@@ -18,6 +18,8 @@
 
 package com.biglybt.core.config;
 
+import com.biglybt.core.config.impl.ConfigurationDefaults;
+
 public final class ConfigKeys {
 	public static final String ICFG_USER_MODE = "User Mode";
 
@@ -115,9 +117,10 @@ public final class ConfigKeys {
 		public static final String BCFG_DEFAULT_DIR_BEST_GUESS = "DefaultDir.BestGuess";
 		public static final String SCFG_DEFAULT_SAVE_PATH = "Default save path";
 		public static final String BCFG_ALWAYS_CREATE_TORRENT_SUB_FOLDER = "Always Create Torrent Sub-Folder";
-		public static final String BCFG_UI_ADDTORRENT_OPENOPTIONS_SEP = "ui.addtorrent.openoptions.sep";
-		public static final String BCFG_DEFAULT_DIR_AUTO_SAVE_AUTO_RENAME = "DefaultDir.AutoSave.AutoRename";
+		public static final String BCFG_UI_ADDTORRENT_OPENOPTIONS_SEP = ConfigurationDefaults.CFG_TORRENTADD_OPENOPTIONS_SEP;
+		public static final String BCFG_UI_ADDTORRENT_OPENOPTIONS_ALWAYS_SIDEBAR = "ui.addtorrent.openoptions.always.sidebar";
 		public static final String ICFG_UI_ADDTORRENT_OPENOPTIONS_AUTO_CLOSE_SECS = "ui.addtorrent.openoptions.auto.close.secs";
+		public static final String BCFG_DEFAULT_DIR_AUTO_SAVE_AUTO_RENAME = "DefaultDir.AutoSave.AutoRename";
 		public static final String BCFG_DEFAULT_DIR_AUTO_UPDATE = "DefaultDir.AutoUpdate";
 		public static final String ICFG_SAVE_TO_LIST_MAX_ENTRIES = "saveTo_list.max_entries";
 		public static final String SCFG_SAVE_TO_LIST = "saveTo_list";
@@ -135,6 +138,7 @@ public final class ConfigKeys {
 		public static final String BCFG_CHECK_PIECES_ON_COMPLETION = "Check Pieces on Completion";
 		public static final String BCFG_CHECK_PIECES_ON_COMPLETION_BEFORE_MOVE = "Check Pieces on Completion Before Move";
 		public static final String BCFG_SEEDING_PIECE_CHECK_RECHECK_ENABLE = "Seeding Piece Check Recheck Enable";
+		public static final String BCFG_UPLOAD_ONLY_ON_WRITE_ERROR_ENABLE = "Switch To Upload Only On Write Error Enable";
 		public static final String BCFG_FILE_STRICT_LOCKING = "File.strict.locking";
 		public static final String ICFG_MAX_FILE_LINKS_SUPPORTED = "Max File Links Supported";
 		public static final String BCFG_INSUFFICIENT_SPACE_DOWNLOAD_RESTART = "Insufficient Space Download Restart Enable";
