@@ -87,6 +87,9 @@ public class ConfigurationDefaults {
 
 
   private final Hashtable parameter_verifiers	= new Hashtable();
+  
+  		// these shouldn't be here as SWT UI specific...
+  
 	public static final String CFG_TORRENTADD_OPENOPTIONS_MANY = "many";
 	public static final String CFG_TORRENTADD_OPENOPTIONS_ALWAYS = "always";
 	public static final String CFG_TORRENTADD_OPENOPTIONS_NEVER = "never";
@@ -163,7 +166,7 @@ public class ConfigurationDefaults {
     def.put("IPV4 Prefer Stack", FALSE );
     def.put(ConfigKeys.Connection.BCFG_IPV_4_IGNORE_NI_ADDRESSES, FALSE );
     def.put(ConfigKeys.Connection.BCFG_IPV_6_IGNORE_NI_ADDRESSES, FALSE );
-    def.put(ConfigKeys.Connection.SCFG_CONNECTION_TEST_DOMAIN, "www.google.com");
+    def.put(ConfigKeys.Connection.SCFG_CONNECTION_TEST_DOMAIN, "www.google.com;nettest.biglybt.com");
 
     def.put("max active torrents", new Long(4));
     def.put("max downloads", new Long(4));
@@ -302,8 +305,11 @@ public class ConfigurationDefaults {
     def.put("User Mode", ZERO);
 
     //default data location options
+    
     def.put( CFG_TORRENTADD_OPENOPTIONS, CFG_TORRENTADD_OPENOPTIONS_ALWAYS);
-    def.put( CFG_TORRENTADD_OPENOPTIONS_SEP, TRUE );
+    def.put( ConfigKeys.File.BCFG_UI_ADDTORRENT_OPENOPTIONS_SEP, TRUE );
+    def.put( ConfigKeys.File.ICFG_UI_ADDTORRENT_OPENOPTIONS_AUTO_CLOSE_SECS, ZERO );
+    def.put( ConfigKeys.File.BCFG_UI_ADDTORRENT_OPENOPTIONS_ALWAYS_SIDEBAR, FALSE );
 
 	File f = null;
 
@@ -452,6 +458,7 @@ public class ConfigurationDefaults {
     def.put( ConfigKeys.File.ICFG_INSUFFICIENT_SPACE_DOWNLOAD_RESTART_MINS, 10 );
     def.put( ConfigKeys.File.BCFG_MISSING_FILE_DOWNLOAD_RESTART, FALSE );
     def.put( ConfigKeys.File.ICFG_MISSING_FILE_DOWNLOAD_RESTART_MINS, 30 );
+    def.put( ConfigKeys.File.BCFG_UPLOAD_ONLY_ON_WRITE_ERROR_ENABLE, FALSE );
 
     def.put( "Play Download Error", FALSE );
     def.put( "Play Download Error File", "" );
