@@ -113,7 +113,8 @@ TranscodeJobOutputLeecher
 	@Override
 	public void
 	setLink(
-		File	link_destination )
+		File	link_destination,
+		boolean	dont_delete )
 	{
 		throw( new RuntimeException( "Not supported" ));
 	}
