@@ -38,9 +38,9 @@ DiskAccessControllerInstance
 	final boolean		invert_threads	= !COConfigurationManager.getBooleanParameter( "diskmanager.perf.queue.torrent.bias" );
 
 	final int	max_threads;
-	private int	max_mb_queued;
+	private int	max_kb_queued;
 
-	private final groupSemaphore	max_mb_sem;
+	private final groupSemaphore	max_kb_sem;
 
 	private long			request_bytes_queued;
 	private long			requests_queued;
@@ -94,9 +94,9 @@ DiskAccessControllerInstance
 		aggregation_request_limit	= _aggregation_request_limit;
 		aggregation_byte_limit		= _aggregation_byte_limit;
 
-		max_mb_queued		= _max_mb;
+		max_kb_queued		= _max_mb*1024;
 
-		max_mb_sem 			= new groupSemaphore( max_mb_queued );
+		max_kb_sem 			= new groupSemaphore( max_kb_queued );
 		max_threads			= _max_threads;
 
 		dispatchers	= new requestDispatcher[invert_threads?1:max_threads];
@@ -115,7 +115,7 @@ DiskAccessControllerInstance
 	protected long
 	getBlockCount()
 	{
-		return( max_mb_sem.getBlockCount());
+		return( max_kb_sem.getBlockCount());
 	}
 
 	protected long
@@ -266,26 +266,24 @@ DiskAccessControllerInstance
 	getSpaceAllowance(
 		DiskAccessRequestImpl	request )
 	{
-		int	mb_diff;
+		int	kb_diff;
 
 		synchronized( torrent_dispatcher_map ){
+			
+			int 	size = request.getSize();
+			
+			request_bytes_queued += size;
 
-			int	old_mb = (int)(request_bytes_queued/(1024*1024));
+			kb_diff = (size+1023)/1024;
 
-			request_bytes_queued += request.getSize();
-
-			int	new_mb = (int)(request_bytes_queued/(1024*1024));
-
-			mb_diff = new_mb - old_mb;
-
-			if ( mb_diff > max_mb_queued ){
+			if ( kb_diff > max_kb_queued ){
 
 					// if this request is bigger than the max allowed queueable then easiest
 					// approach is to bump up the limit
 
-				max_mb_sem.releaseGroup( mb_diff - max_mb_queued );
+				max_kb_sem.releaseGroup( kb_diff - max_kb_queued );
 
-				max_mb_queued	= mb_diff;
+				max_kb_queued	= kb_diff;
 			}
 
 			requests_queued++;
@@ -303,36 +301,31 @@ DiskAccessControllerInstance
 
 				next_request_byte_log += REQUEST_BYTE_LOG_CHUNK;
 			}
+				
+			request.setSpaceAllowance( kb_diff );
 		}
 
-		if ( mb_diff > 0 ){
-
-			max_mb_sem.reserveGroup( mb_diff );
-		}
+		max_kb_sem.reserveGroup( kb_diff );
 	}
 
 	protected void
 	releaseSpaceAllowance(
 		DiskAccessRequestImpl	request )
 	{
-		int	mb_diff;
+		int	kb_diff;
 
 		synchronized( torrent_dispatcher_map ){
 
-			int	old_mb = (int)(request_bytes_queued/(1024*1024));
-
 			request_bytes_queued -= request.getSize();
 
-			int	new_mb = (int)(request_bytes_queued/(1024*1024));
-
-			mb_diff = old_mb - new_mb;
-
 			requests_queued--;
+			
+			kb_diff = request.getSpaceAllowance();
 		}
 
-		if ( mb_diff > 0 ){
+		if ( kb_diff > 0 ){
 
-			max_mb_sem.releaseGroup( mb_diff );
+			max_kb_sem.releaseGroup( kb_diff );
 		}
 	}
 
@@ -343,7 +336,7 @@ DiskAccessControllerInstance
 			name +
 			",agg=" + enable_aggregation +
 			",max_t=" + max_threads +
-			",max_mb=" + max_mb_queued +
+			",max_kb=" + max_kb_queued +
 			",q_byte=" + DisplayFormatters.formatByteCountToKiBEtc( request_bytes_queued ) +
 			",q_req=" + requests_queued +
 			",t_req=" + total_requests +
@@ -750,7 +743,7 @@ DiskAccessControllerInstance
 	{
 		private int value;
 
-		private final List	waiters = new LinkedList();
+		private final List<mutableInteger>	waiters = new LinkedList<>();
 
 		private long	blocks;
 
@@ -930,48 +923,4 @@ DiskAccessControllerInstance
 			}
 		}
 	}
-
-	public static void
-	main(
-		String[]	args )
-	{
-		final groupSemaphore	sem = new groupSemaphore( 9 );
-
-		for (int i=0;i<10;i++){
-
-			new Thread()
-			{
-				@Override
-				public void
-				run()
-				{
-					int	count = 0;
-
-					while( true ){
-
-						int	group =RandomUtils.generateRandomIntUpto( 10 );
-
-						System.out.println( Thread.currentThread().getName() + " reserving " + group );
-
-						sem.reserveGroup( group );
-
-						try{
-							Thread.sleep(5 + RandomUtils.generateRandomIntUpto(5));
-
-						}catch( Throwable e ){
-						}
-
-						sem.releaseGroup( group );
-
-						count++;
-
-						if ( count %100 == 0 ){
-
-							System.out.println( Thread.currentThread().getName() + ": " + count + " ops" );
-						}
-					}
-				}
-			}.start();
-		}
-	}
 }
