@@ -173,7 +173,7 @@ FMFileAccessPieceReorderer
 
 		}catch( Throwable e ){
 
-			throw( new FMFileManagerException( "Piece-reorder file init fail", e ));
+			throw( new FMFileManagerException( FMFileManagerException.OP_OPEN, "Piece-reorder file init fail", e ));
 		}
 	}
 
@@ -356,7 +356,7 @@ FMFileAccessPieceReorderer
 
 		if ( piece_number >= num_pieces ){
 
-			throw( new FMFileManagerException( "Attempt to " + str + " piece " + piece_number + ": last=" + num_pieces ));
+			throw( new FMFileManagerException( is_read?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "Attempt to " + str + " piece " + piece_number + ": last=" + num_pieces ));
 		}
 
 		int	this_piece_size = piece_number==0?first_piece_length:(piece_number==(num_pieces-1)?last_piece_length:piece_size);
@@ -365,7 +365,7 @@ FMFileAccessPieceReorderer
 
 		if ( piece_space <= 0 ){
 
-			throw( new FMFileManagerException( "Attempt to " + str + " piece " + piece_number + ", offset " + piece_offset + " - no space in piece" ));
+			throw( new FMFileManagerException( is_read?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "Attempt to " + str + " piece " + piece_number + ", offset " + piece_offset + " - no space in piece" ));
 		}
 
 		int	rem_space = piece_space;
@@ -504,7 +504,7 @@ FMFileAccessPieceReorderer
 					}
 				}else{
 
-					throw( new FMFileManagerException( "partial write operation" ));
+					throw( new FMFileManagerException( is_read?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "partial write operation" ));
 				}
 
 				return;
@@ -673,7 +673,7 @@ FMFileAccessPieceReorderer
 
 			if ( store_index == -1 ){
 
-				throw( new FMFileManagerException( "piece marked as complete but not yet allocated" ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_WRITE, "piece marked as complete but not yet allocated" ));
 			}
 
 			if ( piece_number == store_index ){
@@ -693,7 +693,7 @@ FMFileAccessPieceReorderer
 
 			if ( swap_piece_number < 1 ){
 
-				throw( new FMFileManagerException( "Inconsistent: failed to find piece to swap" ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_WRITE, "Inconsistent: failed to find piece to swap" ));
 			}
 
 			if ( TRACE ){
@@ -938,7 +938,7 @@ FMFileAccessPieceReorderer
 
 		writeConfig();
 
-		FMFileManagerException e = new FMFileManagerException( error );
+		FMFileManagerException e = new FMFileManagerException( FMFileManagerException.OP_OPEN, error );
 
 		e.setRecoverable( false );
 
@@ -1064,7 +1064,7 @@ FMFileAccessPieceReorderer
 
 		if ( !FileUtil.writeResilientFileWithResult( control_dir, config_file.getName(), map )){
 
-			throw( new FMFileManagerException( "Failed to write control file " + config_file.getAbsolutePath()));
+			throw( new FMFileManagerException( FMFileManagerException.OP_WRITE, "Failed to write control file " + config_file.getAbsolutePath()));
 		}
 	}
 
@@ -1087,7 +1087,7 @@ FMFileAccessPieceReorderer
 
 		if ( !FileUtil.writeResilientFileWithResult( control_dir, control_file, map )){
 
-			throw( new FMFileManagerException( "Failed to write control file " + FileUtil.newFile( control_dir, control_file ).getAbsolutePath()));
+			throw( new FMFileManagerException( FMFileManagerException.OP_WRITE, "Failed to write control file " + FileUtil.newFile( control_dir, control_file ).getAbsolutePath()));
 		}
 
 		if ( TRACE ){
