@@ -30,6 +30,8 @@ import java.io.IOException;
 import java.util.*;
 
 import com.biglybt.core.config.COConfigurationManager;
+import com.biglybt.core.config.ConfigKeys;
+import com.biglybt.core.config.ParameterListener;
 import com.biglybt.core.diskmanager.file.FMFile;
 import com.biglybt.core.diskmanager.file.FMFileManagerException;
 import com.biglybt.core.diskmanager.file.FMFileOwner;
@@ -68,6 +70,22 @@ FMFileImpl
 			});
 	}
 
+	static volatile boolean	switch_to_upload_only_enable;
+	
+	static{
+		 COConfigurationManager.addAndFireParameterListeners(
+			new String[]{
+				ConfigKeys.File.BCFG_UPLOAD_ONLY_ON_WRITE_ERROR_ENABLE,
+			},
+			new ParameterListener(){
+				@Override
+				public void parameterChanged(String parameterName) {
+										
+	    	    	switch_to_upload_only_enable	= COConfigurationManager.getBooleanParameter( ConfigKeys.File.BCFG_UPLOAD_ONLY_ON_WRITE_ERROR_ENABLE );
+				}
+			});
+	}
+	
 	private final FMFileManagerImpl	manager;
 	private final FMFileOwner		owner;
 	
@@ -161,7 +179,7 @@ FMFileImpl
 				throw((FMFileManagerException)e);
 			}
 
-			throw( new FMFileManagerException( "initialisation failed", e ));
+			throw( new FMFileManagerException( FMFileManagerException.OP_OPEN, "initialisation failed", e ));
 
 		}finally{
 
@@ -195,7 +213,7 @@ FMFileImpl
 				throw((FMFileManagerException)e);
 			}
 
-			throw( new FMFileManagerException( "initialisation failed", e ));
+			throw( new FMFileManagerException( FMFileManagerException.OP_OPEN, "initialisation failed", e ));
 		}
 	}
 
@@ -340,12 +358,12 @@ FMFileImpl
 
 			}catch( Throwable e ){
 
-				throw( new FMFileManagerException( "getCanonicalPath fails", e ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "getCanonicalPath fails", e ));
 			}
 
 			if ( new_linked_file.exists()){
 
-				throw( new FMFileManagerException( "moveFile fails - file '" + new_canonical_path + "' already exists"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "moveFile fails - file '" + new_canonical_path + "' already exists"));
 			}
 
 			boolean	was_open	= isOpen();
@@ -387,7 +405,7 @@ FMFileImpl
 					}
 				}
 
-				throw( new FMFileManagerException( "moveFile fails"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "moveFile fails"));
 			}
 		}finally{
 
@@ -436,12 +454,12 @@ FMFileImpl
 
 			}catch( Throwable e ){
 
-				throw( new FMFileManagerException( "getCanonicalPath fails", e ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "getCanonicalPath fails", e ));
 			}
 
 			if ( new_linked_file.exists()){
 
-				throw( new FMFileManagerException( "renameFile fails - file '" + new_canonical_path + "' already exists"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "renameFile fails - file '" + new_canonical_path + "' already exists"));
 			}
 
 			boolean	was_open	= isOpen();
@@ -481,7 +499,7 @@ FMFileImpl
 					}
 				}
 
-				throw( new FMFileManagerException( "renameFile fails"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "renameFile fails"));
 			}
 		}finally{
 
@@ -569,6 +587,28 @@ FMFileImpl
 		}
 	}
 
+	private void
+	getFileAccessor()
+		throws FileNotFoundException
+	{
+		try{
+		
+			fa = FileUtil.newFileAccessor( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
+			
+		}catch( FileNotFoundException e ){
+			
+				// relax to read-only if we are trying to handle switching to upload only on write errors
+			
+			if ( 	switch_to_upload_only_enable && 
+					access_mode == FM_WRITE && 
+					linked_file.exists()  && 
+					linked_file.canRead()){
+				
+				fa = FileUtil.newFileAccessor( linked_file, READ_ACCESS_MODE );
+			}
+		}
+	}
+	
 	protected void
 	reopen(
 		FMFileManagerException		cause )
@@ -597,7 +637,7 @@ FMFileImpl
 
 		file_access.aboutToOpen();
 
-		fa = FileUtil.newFileAccessor( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
+		getFileAccessor();
 
 		last_modified = 0;
 		
@@ -612,7 +652,7 @@ FMFileImpl
 	{
 		if ( fa != null ){
 
-			throw( new FMFileManagerException( "file already open" ));
+			throw( new FMFileManagerException( FMFileManagerException.OP_OPEN, "file already open" ));
 		}
 
 		reserveAccess( reason );
@@ -620,7 +660,7 @@ FMFileImpl
 		try{
 			file_access.aboutToOpen();
 
-			fa = FileUtil.newFileAccessor( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
+			getFileAccessor();
 
 			last_modified = 0;
 			
@@ -638,7 +678,7 @@ FMFileImpl
 
 				linked_file.createNewFile();
 
-				fa = FileUtil.newFileAccessor( linked_file, access_mode==FM_READ?READ_ACCESS_MODE:WRITE_ACCESS_MODE);
+				getFileAccessor();
 
 				last_modified = 0;
 				
@@ -653,13 +693,13 @@ FMFileImpl
 
 				Debug.printStackTrace( e );
 
-				throw( new FMFileManagerException( "open fails for '" + linked_file.getAbsolutePath() + "'", e ));
+				throw( new FMFileManagerException( access_mode==FM_READ?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "open fails for '" + linked_file.getAbsolutePath() + "'", e ));
 			}
 		}catch( Throwable e ){
 
 			Debug.printStackTrace( e );
 
-			throw( new FMFileManagerException( "open fails for '" + linked_file.getAbsolutePath() + "'", e ));
+			throw( new FMFileManagerException( access_mode==FM_READ?FMFileManagerException.OP_READ:FMFileManagerException.OP_WRITE, "open fails for '" + linked_file.getAbsolutePath() + "'", e ));
 		}
 	}
 
@@ -696,7 +736,7 @@ FMFileImpl
 
 			}catch( Throwable e ){
 
-				throw( new FMFileManagerException("close fails", e ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_CLOSE, "close fails", e ));
 
 			}finally{
 
@@ -755,7 +795,7 @@ FMFileImpl
 
 			if ( !linked_file.delete()){
 
-				throw( new FMFileManagerException( "Failed to delete '" + linked_file + "'" ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "Failed to delete '" + linked_file + "'" ));
 			}
 		}
 	}
@@ -909,7 +949,7 @@ FMFileImpl
 							
 							if ( this_torrent == my_torrent && this_tf != my_torrent_file ){
 								
-								throw( new FMFileManagerException(  "File '"+canonical_path + "' occurs more than once in download.\nRename one of the files in Files view via the right-click menu." ));
+								throw( new FMFileManagerException(  FMFileManagerException.OP_OTHER, "File '"+canonical_path + "' occurs more than once in download.\nRename one of the files in Files view via the right-click menu." ));
 							}
 						}
 					}
@@ -963,7 +1003,7 @@ FMFileImpl
 
 				Debug.out( "reserveAccess fail" );
 
-				throw( new FMFileManagerException( "File '"+canonical_path+"' has not been reserved (no entries), '" + owner.getName()+"'"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "File '"+canonical_path+"' has not been reserved (no entries), '" + owner.getName()+"'"));
 			}
 
 			for ( Object[] entry: owners ){
@@ -982,7 +1022,7 @@ FMFileImpl
 
 				Debug.out( "reserveAccess fail" );
 
-				throw( new FMFileManagerException( "File '"+canonical_path+"' has not been reserved (not found), '" + owner.getName()+"'"));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, "File '"+canonical_path+"' has not been reserved (not found), '" + owner.getName()+"'"));
 			}
 
 			my_entry[1] = Boolean.valueOf(access_mode == FM_WRITE);
@@ -1093,7 +1133,7 @@ FMFileImpl
 				
 				Debug.out( "reserveAccess fail: " + str );
 				
-				throw( new FMFileManagerException( str ));
+				throw( new FMFileManagerException( FMFileManagerException.OP_OTHER, str ));
 			}
 
 		}finally{
@@ -1201,7 +1241,7 @@ FMFileImpl
 
 				}else{
 
-					FMFileManagerException error = new FMFileManagerException( MessageText.getString( "DownloadManager.error.datamissing" ) + ": " + target.getAbsolutePath());
+					FMFileManagerException error = new FMFileManagerException( FMFileManagerException.OP_OTHER, MessageText.getString( "DownloadManager.error.datamissing" ) + ": " + target.getAbsolutePath());
 					
 					error.setType(FMFileManagerException.ET_FILE_OR_DIR_MISSING );
 					
