@@ -95,8 +95,9 @@ DownloadManagerState
 	public static final String AT_MASK_DL_COMP_OPTIONAL		= "mdlc";			// Boolean (optional)
 	public static final String AT_REAL_DM_MAGNET_TIME		= "rdmmt";			// long
 	public static final String AT_PLUGIN_OPTIONS			= "pluginoptions";	// Map
-	public static final String 		AT_PO_ENABLE_ANNOUNCE		= "enableannounce";		// boolean, def=true
+	public static final String AT_PO_ENABLE_ANNOUNCE		= "enableannounce";		// boolean, def=true
 	public static final String AT_SET_FILE_PRIORITY_REM_PIECE	= "sfp.rp";		// int
+	public static final String AT_LAST_SCRAPE_TIME			= "lastscrape";		// long
 
 	public static final String AT_TRANSIENT_FLAGS			= "t_flags";
 	public static final String AT_TRANSIENT_TAG_SORT		= "t_tagsort";
@@ -181,6 +182,7 @@ DownloadManagerState
 
 	public static final int	TRANSIENT_FLAG_FRIEND_FP	= 0x00000001;
 	public static final int	TRANSIENT_FLAG_TAG_FP		= 0x00000002;
+	public static final int	TRANSIENT_FLAG_TAG_NOT_FP	= 0x00000004;
 	
 			
 	public TOTorrent
