@@ -1061,6 +1061,8 @@ DownloadManagerStatsImpl
 		int max_rate_bps )
 	{
 		max_upload_rate_bps = max_rate_bps;
+		
+		download_manager.rateLimitChanged();
 	}
 
 	@Override
@@ -1075,12 +1077,9 @@ DownloadManagerStatsImpl
 	setDownloadRateLimitBytesPerSecond(
 		int max_rate_bps )
 	{
-		if ( Constants.IS_CVS_VERSION && max_download_rate_bps == -1 && max_rate_bps != -1 ){
-			
-			Debug.out( "Download changed from disabled to " + max_rate_bps + " for " + download_manager.getDisplayName());
-		}
-		
 		max_download_rate_bps = max_rate_bps;
+		
+		download_manager.rateLimitChanged();
 	}
 
 	@Override
@@ -1546,11 +1545,15 @@ DownloadManagerStatsImpl
 		saved_peak_receive_rate		= state.getLongAttribute( DownloadManagerState.AT_PEAK_RECEIVE_RATE );
 		saved_peak_send_rate		= state.getLongAttribute( DownloadManagerState.AT_PEAK_SEND_RATE );
 
+		/*
+		 * 24/06/2024. going to assume that this bug has long since been fixed and any potential recovery 
+		 * performed. It is causing cache-fixups on restart for downloads that legitimately have 0 completed data
 		if (saved_data_bytes_downloaded > 0 && saved_completed_download_bytes == 0) {
 			// Bug where 0 is stored in config for torrent's saved_completed_download_bytes
 			// when there's actually completed data.  Force a recalc on next request
 			saved_completed_download_bytes = -1;
 		}
+		*/
 		
 		loadTrackerStats();
 	}
