@@ -589,7 +589,7 @@ DownloadHistoryManagerImpl
 		}
 	}
 
-	private List<DownloadHistory>
+	public List<DownloadHistory>
 	getHistory()
 	{
 		synchronized( lock ){
@@ -1219,8 +1219,8 @@ DownloadHistoryManagerImpl
 		private String			name;
 		private String			save_location;
 		private String[]		tags			= NO_TAGS;
-		private long			complete_time	= -1;
-		private long			remove_time		= -1;
+		private long			complete_time	= 0;
+		private long			remove_time		= 0;
 
 		private Map<Long,DownloadHistoryImpl>	history_ref;	// need this for GC purposes
 
@@ -1292,9 +1292,21 @@ DownloadHistoryManagerImpl
 				size = l_size==null?0:l_size;
 
 				add_time 		= (Long)map.get( "a" );
+				
 				complete_time 	= (Long)map.get( "c" );
+				
+				if ( complete_time < 0 ){
+					
+					complete_time = 0;	// switch to using 0 as "none" to keep Droo happy
+				}
+				
 				remove_time 	= (Long)map.get( "r" );
 
+				if ( remove_time < 0 ){
+					
+					remove_time = 0;	// switch to using 0 as "none" to keep Droo happy
+				}
+
 				List<byte[]> l_tags = (List<byte[]>)map.get( "t" );
 				
 				if ( l_tags != null ){
@@ -1364,22 +1376,25 @@ DownloadHistoryManagerImpl
 			result.put( SearchResult.PR_SIZE, size );
 			result.put( SearchResult.PR_HASH, hash );
 			result.put( SearchResult.PR_PUB_DATE, new Date( add_time ));
-			
-			String magnet = UrlUtils.getMagnetURI( getTorrentHash(), getTorrentV2Hash(), getName(), null );
-			
-			if ( tags != null && tags.length > 0 ){
-			
-				result.put( SearchResult.PR_TAGS, tags );
+						
+			if ( hash != null ){
 				
-				for ( String tag: tags ){
+				String magnet = UrlUtils.getMagnetURI( hash, getTorrentV2Hash(), getName(), null );
+				
+				if ( tags != null && tags.length > 0 ){
+				
+					result.put( SearchResult.PR_TAGS, tags );
 					
-					magnet += "&tag=" + UrlUtils.encode( tag );
+					for ( String tag: tags ){
+						
+						magnet += "&tag=" + UrlUtils.encode( tag );
+					}
 				}
+	
+				result.put( SearchResult.PR_TORRENT_LINK, magnet );
+				//result.put( SearchResult.PR_DOWNLOAD_LINK, magnet );
 			}
 
-			result.put( SearchResult.PR_TORRENT_LINK, magnet );
-			//result.put( SearchResult.PR_DOWNLOAD_LINK, magnet );
-
 			return( result );
 		}
 		
@@ -1393,14 +1408,25 @@ DownloadHistoryManagerImpl
 
 			if ( comp == 0 ){
 
-				complete_time = dms.getLongParameter( DownloadManagerState.PARAM_DOWNLOAD_COMPLETED_TIME );	// nothing recorded either way
+				comp = dms.getLongParameter( DownloadManagerState.PARAM_DOWNLOAD_COMPLETED_TIME );	// nothing recorded either way
 
-			}else{
-
-				complete_time = comp;
+			}
+			
+			if ( comp < 0 ){
+				
+				comp = 0;
 			}
 
-			return( complete_time != old_time );
+			if ( comp != old_time ){
+				
+				complete_time = comp;
+
+				return( true );
+				
+			}else{
+				
+				return( false );
+			}
 		}
 
 		boolean
