@@ -386,26 +386,27 @@ IpFilterImpl
 	public boolean
 	isInRange(
 		String 	ipAddress,
-		String 	torrent_name,
+		String 	name,
 		byte[]	torrent_hash )
 	{
-		return( isInRange( ipAddress, torrent_name, torrent_hash, true ));
+		return( isInRange( ipAddress, name, torrent_hash, false, true ));
 	}
 
 	@Override
 	public boolean
 	isInRange(
 		String ipAddress,
-		String torrent_name,
+		String name,
 		byte[] torrent_hash,
+		boolean	is_specific,
 		boolean	loggable )
 	{
-		//In all cases, block banned ip addresses
+			//In all cases, block banned ip addresses
+		
+		if ( ipBanner.isBanned(ipAddress, is_specific?torrent_hash:null )){
 
-		  if( ipBanner.isBanned(ipAddress)){
-
-			  return true;
-		  }
+			return true;
+		}
 
 
 		if ( !isEnabled()){
@@ -488,7 +489,7 @@ IpFilterImpl
 			  return( false );
 		  }
 
-	      if ( addBlockedIP( new BlockedIpImpl( ipAddress, match, torrent_name, loggable), torrent_hash, loggable )){
+	      if ( addBlockedIP( new BlockedIpImpl( ipAddress, match, name, loggable), torrent_hash, loggable )){
 
 		      if (Logger.isEnabled())
 						Logger.log(new LogEvent(LOGID_NWMAN, "Ip Blocked : "
@@ -517,7 +518,7 @@ IpFilterImpl
 		  return( false );
 		}
 
-	    if ( addBlockedIP( new BlockedIpImpl(ipAddress,null, torrent_name, loggable), torrent_hash, loggable )){
+	    if ( addBlockedIP( new BlockedIpImpl(ipAddress,null, name, loggable), torrent_hash, loggable )){
 
 		    if (Logger.isEnabled())
 					Logger.log(new LogEvent(LOGID_NWMAN, "Ip Blocked : "
@@ -543,13 +544,14 @@ IpFilterImpl
 	public boolean
 	isInRange(
 		InetAddress ipAddress,
-		String 		torrent_name,
+		String 		name,
 		byte[] 		torrent_hash,
+		boolean		is_specific,
 		boolean		loggable )
 	{
 		//In all cases, block banned ip addresses
 
-		if( ipBanner.isBanned(ipAddress)){
+		if( ipBanner.isBanned(ipAddress,is_specific?torrent_hash:null)){
 
 			return true;
 		}
@@ -617,7 +619,7 @@ IpFilterImpl
 
 	    if(!allow) {
 
-	      if ( addBlockedIP( new BlockedIpImpl(ipAddress.getHostAddress(),match, torrent_name, loggable), torrent_hash, loggable )){
+	      if ( addBlockedIP( new BlockedIpImpl(ipAddress.getHostAddress(),match, name, loggable), torrent_hash, loggable )){
 
 		      if (Logger.isEnabled())
 						Logger.log(new LogEvent(LOGID_NWMAN, "Ip Blocked : "
@@ -642,7 +644,7 @@ IpFilterImpl
 
 	  if( allow ){
 
-	    if ( addBlockedIP( new BlockedIpImpl(ipAddress.getHostAddress(),null, torrent_name, loggable), torrent_hash, loggable )){
+	    if ( addBlockedIP( new BlockedIpImpl(ipAddress.getHostAddress(),null, name, loggable), torrent_hash, loggable )){
 
 		    if (Logger.isEnabled())
 					Logger.log(new LogEvent(LOGID_NWMAN, "Ip Blocked : "
@@ -934,15 +936,32 @@ IpFilterImpl
 	public boolean
 	ban(
 		String 		ipAddress,
-		String		torrent_name,
+		String		name,
 		boolean		manual )
 	{
-		return( ban( ipAddress, torrent_name, manual, 0 ));
+		return( ban( ipAddress, name, null, manual ));
+	}
+	
+	@Override
+	public boolean
+	ban(
+		String 		ipAddress,
+		String		name,
+		byte[]		specific_hash,
+		boolean		manual )
+	{
+		return( ban( ipAddress, name, specific_hash, manual, 0 ));
 	}
 
-
-
-
+	@Override
+	public boolean 
+	isBanned(
+		String ipAddress, 
+		byte[] specific_hash)
+	{
+		return( ipBanner.isBanned( ipAddress, specific_hash ));
+	}
+	
 	@Override
 	public BlockedIp[]
 	getBlockedIps()
@@ -1127,11 +1146,22 @@ IpFilterImpl
 	public boolean 
 	ban(
 		String 		ipAddress, 
-		String 		torrent_name, 
+		String 		name, 
 		boolean 	manual, 
 		int 		for_mins )
 	{
-		return( ipBanner.ban( ipAddress, torrent_name, manual, for_mins ));
+		return( ban( ipAddress, name, null, manual, for_mins ));
+	}
+	
+	private boolean
+	ban(
+		String 		ipAddress, 
+		String 		name, 
+		byte[]		specific_hash,
+		boolean 	manual, 
+		int 		for_mins )
+	{
+		return( ipBanner.ban( ipAddress, name, specific_hash, manual, for_mins ));
 	}
 	
 	@Override
