@@ -610,8 +610,12 @@ WebEngine
 
 		boolean user_tor = false;
 
-		if ( !explicit_tor ){
+		if ( explicit_tor ){
 
+			can_proxy = true;
+			
+		}else{
+			
 			String test = Result.adjustLink( searchURL );
 
 			if ( test.startsWith( "tor:" )){
@@ -623,8 +627,11 @@ WebEngine
 
 		boolean user_i2p = false;
 
-		if ( !explicit_i2p ){
+		if ( explicit_i2p ){
 
+			can_proxy = true;
+			
+		}else{
 			String test = Result.adjustLink( searchURL );
 
 			if ( test.startsWith( "i2p:" )){
