@@ -48,11 +48,14 @@ PeerControlSchedulerBasic
 	private long	latest_time;
 	private long	last_lag_log;
 
-	private long	next_peer_count_time = SystemTime.getMonotonousTime();
+	private long	next_peer_count_time 	= SystemTime.getMonotonousTime();
+	private long	next_piece_count_time	= SystemTime.getMonotonousTime();
 	
-	private volatile long		peer_count_active_time = 0;
+	private volatile long		peer_count_active_time 	= 0;
+	private volatile long		piece_count_active_time = 0;
 	
-	private volatile int		last_peer_count[] = { 0, 0 };
+	private volatile int		last_peer_count[] 	= { 0, 0 };
+	private volatile int		last_piece_count[] 	= { 0, 0 };
 
 	
 	@Override
@@ -67,7 +70,8 @@ PeerControlSchedulerBasic
 				consume(
 					long	time )
 				{
-					boolean count_them = false;
+					boolean count_peers 	= false;
+					boolean count_pieces 	= false;
 					
 					synchronized( PeerControlSchedulerBasic.this ){
 
@@ -80,33 +84,68 @@ PeerControlSchedulerBasic
 									peer_count_active_time = 0;
 									
 								}else{
-									count_them = true;
+									count_peers = true;
 									
 									next_peer_count_time = time+900;
 								}
 							}
 						}
 						
+						if ( piece_count_active_time > 0 ){
+							
+							if ( time >= next_piece_count_time ){
+								
+								if ( time - piece_count_active_time > 15*1000 ){
+									
+									piece_count_active_time = 0;
+									
+								}else{
+									
+									count_pieces = true;
+									
+									next_piece_count_time = time+900;
+								}
+							}
+						}
 						PeerControlSchedulerBasic.this.notify();
 					}
 					
-					if ( count_them ){
+					if ( count_peers || count_pieces ){
 						
-						int count1 = 0;
-						int count2 = 0;
+						int peer_count1 = 0;
+						int peer_count2 = 0;
+						
+						int piece_count1 = 0;
+						int piece_count2 = 0;
 						
 						synchronized( instance_lock ){
 							
 							for ( PeerControlInstance i: instance_map.keySet()){
 								
-								int[] c = i.getPeerCount();
+								if ( count_peers ){
+									
+									int[] c = i.getPeerCount();
+									
+									peer_count1 += c[0];
+									peer_count2 += c[01];
+								}
 								
-								count1 += c[0];
-								count2 += c[01];
+								if ( count_pieces ){
+									
+									int[] c = i.getPieceCount();
+									
+									piece_count1 += c[0];
+									piece_count2 += c[01];
+								}
 							}
 						}
 						
-						last_peer_count = new int[]{ count1, count2 };
+						if ( count_peers ){
+							last_peer_count = new int[]{ peer_count1, peer_count2 };
+						}
+						if ( count_pieces ){
+							last_piece_count = new int[]{ piece_count1, piece_count2 };
+						}
 					}
 				}
 			});
@@ -281,6 +320,14 @@ PeerControlSchedulerBasic
 		return( last_peer_count );
 	}
 	
+	@Override
+	public int[] getPieceCount()
+	{
+		piece_count_active_time = SystemTime.getMonotonousTime();
+		
+		return( last_piece_count );
+	}
+
 	protected class
 	instanceWrapper
 	{
