@@ -44,12 +44,18 @@ SearchSubsResultBase
 	public int
 	getNbSeeds();
 	
+	public int
+	getNbPeers();
+	
 	public String
 	getSeedsPeers();
 
 	public long
 	getSeedsPeersSortValue();
 
+	public int
+	getNbCompleted();
+	
 	public String
 	getVotesComments();
 
