@@ -1,25 +1,21 @@
 /*
- * Created on Dec 2, 2016
- * Created by Paul Gardner
+ * Copyright (C) Bigly Software.  All Rights Reserved.
  *
- * Copyright 2016 Azureus Software, Inc.  All rights reserved.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-
 package com.biglybt.core.subs.util;
 
 import java.util.*;
@@ -92,8 +88,10 @@ SubscriptionResultFilterable
 			}
 		}
 
-		size = (Long)properties.get( SearchResult.PR_SIZE );
+		Long l_size = (Long)properties.get( SearchResult.PR_SIZE );
 
+		size = l_size==null?0:l_size;
+		
 		String tl = (String)properties.get( SearchResult.PR_TORRENT_LINK );
 
 		if ( tl == null ){
