@@ -3,6 +3,8 @@ package com.biglybt.core.util;
 import java.util.*;
 
 import com.biglybt.core.devices.Device;
+import com.biglybt.core.peer.PEPeer;
+import com.biglybt.pif.peers.Peer;
 import com.biglybt.pifimpl.local.PluginCoreUtils;
 
 public class 
@@ -60,6 +62,14 @@ DataSourceResolver
 			
 			return( null );
 			
+		}else if ( data_source instanceof Peer ){
+			
+			return( exportDataSource(((Peer)data_source).getDescriptor()));
+			
+		}else if ( data_source instanceof PEPeer ){
+			
+			return( exportDataSource(((PEPeer)data_source).getDescriptor()));
+			
 		}else if ( data_source == DEFAULT_DATASOURCE ){
 			
 			return( null );
@@ -227,8 +237,18 @@ DataSourceResolver
 	public interface
 	ExportableDataSource
 	{
+		public static final int OPT_ON_TOP			= 0;
+		public static final int OPT_CAN_MINIMIZE	= 1;
+		
 		public ExportedDataSource
 		exportDataSource();
+		
+		public default Boolean
+		getBooleanOption(
+			int		opt )
+		{
+			return( null );
+		}
 	}
 	
 	public interface
