@@ -935,7 +935,8 @@ public class UrlUtils
 			url.startsWith( "azplug:") ||
 			url.startsWith( "vuze:") ||
 			url.startsWith( "biglybt:") ||
-			url.startsWith( "tor:" ));
+			url.startsWith( "tor:" ) ||
+			url.startsWith( "i2p:" ));
 	}
 
 	public static String parseTextForURL(String text, boolean accept_magnets,
@@ -965,6 +966,14 @@ public class UrlUtils
 			}
 		}
 
+		if ( text.startsWith( "i2p:" )){
+
+			String href = parseTextForURL(text.substring(4), false, false );
+			if (href != null) {
+				return( "i2p:" + href );
+			}
+		}
+
 		String href = parseHTMLforURL(text);
 		if (href != null) {
 			return href;
@@ -2024,6 +2033,7 @@ public class UrlUtils
 
 
 		try{
+			/*
 			Object sni_host_name = Class.forName( "javax.net.ssl.SNIHostName").getConstructor( String.class ).newInstance( host_name );
 
 			List<Object> sni_host_names = new ArrayList<>(1);
@@ -2036,17 +2046,20 @@ public class UrlUtils
 
 			ssl_parameters_class.getMethod( "setServerNames", List.class ).invoke( ssl_parameters, sni_host_names );
 
-			socket.getClass().getMethod( "setSSLParameters" , ssl_parameters_class ).invoke( socket, ssl_parameters );
-
-			/*
-			SNIHostName serverName = new SNIHostName("whatever.com");
+			SSLSocket.class.getMethod( "setSSLParameters" , ssl_parameters_class ).invoke( socket, ssl_parameters );
+			*/
+			
+			SNIHostName serverName = new SNIHostName( host_name );
+			
 			List<SNIServerName> serverNames = new ArrayList<>(1);
+			
 			serverNames.add(serverName);
 
 			SSLParameters params = socket.getSSLParameters();
+			
 			params.setServerNames(serverNames);
+			
 			socket.setSSLParameters(params);
-			*/
 
 			return( true );
 
@@ -2321,7 +2334,7 @@ public class UrlUtils
 		int			connect_timeout,
 		int			read_timeout )
 
-		throws Exception
+		throws Throwable
 	{
 
 		return( connectSocketAndWrite( is_ssl, target_host, target_port, bytes, connect_timeout, read_timeout, false ));
@@ -2337,7 +2350,54 @@ public class UrlUtils
 		int			read_timeout,
 		boolean		unconnected_socket_hack )
 
-		throws Exception
+		throws Throwable
+	{
+		List<InetAddress[]> binds =  NetworkAdmin.getSingleton().getSingleHomedServiceBindings( target_host );
+
+		Throwable last_error = null;
+		
+		for( InetAddress[] bind: binds ){
+			
+			try{
+				return(
+					connectSocketAndWrite(
+						is_ssl,
+						target_host,
+						bind[1],
+						bind[0],
+						target_port,
+						bytes,
+						connect_timeout,
+						read_timeout,
+						unconnected_socket_hack ));
+				
+			}catch( Throwable e ){
+				
+				last_error = e;
+			}
+		}
+		
+		if ( last_error != null ){
+			
+			throw( last_error );
+		}
+		
+		throw( new Exception( "hmm"));
+	}
+	
+	public static Socket
+	connectSocketAndWrite(
+		boolean			is_ssl,
+		String			target_host_name,
+		InetAddress		bind_ip,
+		InetAddress		target_host,
+		int				target_port,
+		byte[]			bytes,
+		int				connect_timeout,
+		int				read_timeout,
+		boolean			unconnected_socket_hack )
+
+		throws Throwable
 	{
 		boolean	cert_hack			= false;
 		boolean	dh_hack 			= false;
@@ -2355,17 +2415,8 @@ public class UrlUtils
 			boolean	ok = false;
 
 			try{
-
-				// InetSocketAddress targetSockAddress = new InetSocketAddress(  InetAddress.getByName(target_host) , target_port  );
-
-			    // InetAddress bindIP = NetworkAdmin.getSingleton().getSingleHomedServiceBindAddress(targetSockAddress.getAddress() instanceof Inet6Address ? NetworkAdmin.IP_PROTOCOL_VERSION_REQUIRE_V6 : NetworkAdmin.IP_PROTOCOL_VERSION_REQUIRE_V4);
-				
-			    InetAddress[] bindDetails = NetworkAdmin.getSingleton().getSingleHomedServiceBinding( target_host );
-
-			    InetSocketAddress targetSockAddress = new InetSocketAddress( bindDetails[0], target_port );
-			    
-			    InetAddress bindIP	= bindDetails[1];
-			    
+			    InetSocketAddress targetSockAddress = new InetSocketAddress( target_host, target_port );
+			    			    
 				if ( is_ssl ){
 
 					TrustManager[] tms_delegate = SESecurityManager.getAllTrustingTrustManager();
@@ -2387,13 +2438,13 @@ public class UrlUtils
 
 					if ( unconnected_socket_hack ){
 
-						if ( bindIP == null ){
+						if ( bind_ip == null ){
 
 							target = factory.createSocket(targetSockAddress.getAddress(), targetSockAddress.getPort());
 
 						}else{
 
-							target = factory.createSocket(targetSockAddress.getAddress(), targetSockAddress.getPort(), bindIP, 0 );
+							target = factory.createSocket(targetSockAddress.getAddress(), targetSockAddress.getPort(), bind_ip, 0 );
 						}
 					}else{
 
@@ -2403,13 +2454,13 @@ public class UrlUtils
 
 					if ( unconnected_socket_hack ){
 
-						if ( bindIP == null ){
+						if ( bind_ip == null ){
 
 							target = new Socket(targetSockAddress.getAddress(), targetSockAddress.getPort());
 
 						}else{
 
-							target = new Socket(targetSockAddress.getAddress(), targetSockAddress.getPort(), bindIP, 0 );
+							target = new Socket(targetSockAddress.getAddress(), targetSockAddress.getPort(), bind_ip, 0 );
 						}
 					}else{
 
@@ -2419,16 +2470,16 @@ public class UrlUtils
 
 				if ( internal_error_hack ){
 
-					SSLSocketSNIHack( target_host, (SSLSocket)target );
+					SSLSocketSNIHack( target_host_name, (SSLSocket)target );
 				}
 
 				target.setSoTimeout( read_timeout );
 
 				if ( !unconnected_socket_hack ){
 
-			        if ( bindIP != null ){
+			        if ( bind_ip != null ){
 
-			        	target.bind( new InetSocketAddress( bindIP, 0 ) );
+			        	target.bind( new InetSocketAddress( bind_ip, 0 ) );
 			        }
 
 			        target.connect( targetSockAddress, connect_timeout );
@@ -2470,7 +2521,7 @@ public class UrlUtils
 
 						cert_hack = true;
 
-						SESecurityManager.installServerCertificates( new URL( "https://" + target_host +  ":" + target_port + "/" ));
+						SESecurityManager.installServerCertificates( new URL( "https://" + target_host.getHostAddress() +  ":" + target_port + "/" ));
 
 						hacks_to_do = true;
 					}
@@ -2494,4 +2545,47 @@ public class UrlUtils
 
 		throw( last_error );
 	}
+	
+	public static List<InetSocketAddress>
+	getURLAddresses(
+		URL		url )
+	{
+		String	host	= url.getHost();
+		int		port	= url.getPort()==-1?url.getDefaultPort():url.getPort();
+			
+		if ( port == -1 ){
+			
+			port = 80;
+		}
+		
+		List<InetAddress> addresses = null;
+			
+		try{
+			addresses = DNSUtils.getSingleton().getAllByName( host );
+				
+		}catch( Throwable e ){
+				
+			try{
+				addresses = Arrays.asList( InetAddress.getAllByName( host ));
+					
+			}catch( Throwable f ){
+			}
+		}
+		
+		List<InetSocketAddress> result = new ArrayList<>();
+		
+		if ( addresses == null ){
+			
+			result.add( new InetSocketAddress( host, port ));
+			
+		}else{
+			
+			for ( InetAddress ia: addresses ){
+				
+				result.add( new InetSocketAddress( ia, port ));
+			}
+		}
+		
+		return( result );
+	}
 }
