@@ -282,6 +282,29 @@ DDBaseTTTorrent
 						return( null );
 					}
 					
+					String contact_net = AENetworkClassifier.categoriseAddress( contact.getAddress());
+					
+					String[] nets = dms.getNetworks();
+					
+					boolean net_ok = false;
+					
+					for ( String n: nets ){
+						
+						if ( n == contact_net ){
+							
+							net_ok = true;
+							
+							break;
+						}
+					}
+					
+					if ( !net_ok){
+						
+						ddb.log( "TorrentDownload: request from " + originator + "  for '" + download.getName() + "' denied as network '" + contact_net + "' is disabled" );
+	
+						return( null );
+					}
+					
 					if ( dms.getFlag( DownloadManagerState.FLAG_METADATA_DOWNLOAD )){
 						
 						return( null );
