@@ -119,7 +119,7 @@ PluginInstallerImpl
 
 										File temp_dir = AETemporaryFileHandler.createTempDir();
 
-										File temp_file = new File( temp_dir, id + "_" + version + "." + suffix );
+										File temp_file = FileUtil.newFile( temp_dir, id + "_" + version + "." + suffix );
 
 										FileUtil.copyFile( new ByteArrayInputStream( plugin_file ), temp_file );
 
@@ -453,7 +453,7 @@ PluginInstallerImpl
 
 					File temp_dir = AETemporaryFileHandler.createTempDir();
 
-					File temp_file = new File( temp_dir, id + "_" + version + "." + suffix );
+					File temp_file = FileUtil.newFile( temp_dir, id + "_" + version + "." + suffix );
 
 					FileUtil.copyFile( new ByteArrayInputStream( plugin_file ), temp_file );
 
@@ -691,30 +691,30 @@ PluginInstallerImpl
 					}
 				}
 
-				String	target_dir;
+				File	target_dir;
 
 				if ( shared ){
 
-					target_dir 	= FileUtil.getApplicationFile( "plugins" ).toString();
+					target_dir 	= FileUtil.getApplicationFile( "plugins" );
 
 				}else{
 
-					target_dir 	= FileUtil.getUserFile( "plugins" ).toString();
+					target_dir 	= FileUtil.getUserFile( "plugins" );
 				}
 
-				target_dir += File.separator + plugin_id;
+				target_dir = FileUtil.newFile(target_dir, plugin_id);
 
 					// this may fail on Vista but it doesn't matter as we recover this later
 					// on. So *don't* check for success here
 
-				new File( target_dir ).mkdir();
+				target_dir.mkdir();
 
 				if ( existing_plugin == null ){
 
 						// create a dummy plugin at version 0.0 to trigger the "upgrade" to the new
 						// installed version
 
-					FailedPlugin	dummy_plugin = new FailedPlugin( plugin_id, target_dir );
+					FailedPlugin	dummy_plugin = new FailedPlugin( plugin_id, target_dir.toString() );
 
 					PluginManager.registerPlugin( dummy_plugin, plugin_id );
 
@@ -858,7 +858,7 @@ PluginInstallerImpl
 
 			String	plugin_dir = pi.getPluginDirectoryName();
 
-			if ( plugin_dir == null || !new File(plugin_dir).exists()){
+			if ( plugin_dir == null || !FileUtil.newFile(plugin_dir).exists()){
 
 				throw( new PluginException( "Plugin '" + pi.getPluginID() + "' is not loaded from the file system, can't uninstall" ));
 			}
@@ -906,7 +906,7 @@ PluginInstallerImpl
 						{
 							try{
 								ResourceDownloader rd =
-									manager.getDefaultPluginInterface().getUtilities().getResourceDownloaderFactory().create( new File( plugin_dir ));
+									manager.getDefaultPluginInterface().getUtilities().getResourceDownloaderFactory().create( FileUtil.newFile( plugin_dir ));
 
 									// the plugin may have > 1 plugin interfaces, make the name up appropriately
 
@@ -971,7 +971,7 @@ PluginInstallerImpl
 
 															pi.getPluginState().unload();
 
-															if ( !FileUtil.recursiveDelete( new File( plugin_dir ))){
+															if ( !FileUtil.recursiveDelete( FileUtil.newFile( plugin_dir ))){
 
 																update.setRestartRequired( Update.RESTART_REQUIRED_YES );
 
@@ -983,7 +983,7 @@ PluginInstallerImpl
 
 														UpdateInstaller installer = checker.createInstaller();
 
-														installer.addRemoveAction( new File( plugin_dir ).getCanonicalPath());
+														installer.addRemoveAction( FileUtil.newFile( plugin_dir ).getCanonicalPath());
 
 														update.complete( true );
 
