@@ -183,6 +183,7 @@ ShareResourceFileOrDirImpl
 			URL[]	urls = manager.getAnnounceURLs();
 
 			TOTorrentCreator creator = TOTorrentFactory.createFromFileOrDirWithComputedPieceLength(
+										TOTorrent.TT_V1,
 										file,
 										urls[0],
 										manager.getAddHashes());
@@ -368,7 +369,7 @@ ShareResourceFileOrDirImpl
 
 		throws ShareException
 	{
-		File file = new File(new String((byte[]) map.get("file"), Constants.DEFAULT_ENCODING_CHARSET));
+		File file = FileUtil.newFile(new String((byte[]) map.get("file"), Constants.DEFAULT_ENCODING_CHARSET));
 
 		if (type == ST_FILE) {
 			return new ShareResourceFileImpl(manager, file, map);
@@ -399,23 +400,6 @@ ShareResourceFileOrDirImpl
 
 		item.serialiseItem( map );
 	}
-
-	@Override
-	protected ShareResource 
-	lookupShare(byte[] torrent_hash){
-		try{
-			if ( Arrays.equals( item.getTorrent().getHash(), torrent_hash )){
-				
-				return( this );
-			}
-			
-		}catch( Throwable e ){
-			
-			Debug.out( e );
-		}
-		
-		return( null );
-	}
 	
 	@Override
 	protected void
