@@ -43,6 +43,9 @@ ParameterGroupImpl
 
 	private ParameterTabFolderImpl		tab_folder;
 
+
+	private String id;
+
 	public
 	ParameterGroupImpl(
 			String			_resource,
@@ -181,5 +184,13 @@ ParameterGroupImpl
 	public Object getValueObject() {
 		return null;
 	}
+
+	public String getId() {
+		return id;
+	}
+
+	public void setId(String id) {
+		this.id = id;
+	}
 }
 
