@@ -68,6 +68,8 @@ import com.biglybt.pif.ui.UIInstance;
 import com.biglybt.pif.ui.UIManagerListener;
 import com.biglybt.pif.ui.config.BooleanParameter;
 import com.biglybt.pif.ui.config.ConfigSection;
+import com.biglybt.pif.ui.config.DirectoryParameter;
+import com.biglybt.pif.ui.config.FileParameter;
 import com.biglybt.pif.ui.config.IntParameter;
 import com.biglybt.pif.ui.config.Parameter;
 import com.biglybt.pif.ui.config.StringListParameter;
@@ -140,6 +142,7 @@ MagnetPlugin
 	private BooleanParameter	magnet_recovery;
 	private IntParameter	 	magnet_recovery_concurrency;
 	private BooleanParameter	magnet_rename;
+	private DirectoryParameter	storage_folder;
 
 	private Map<String,BooleanParameter> net_params = new HashMap<>();
 
@@ -223,6 +226,8 @@ MagnetPlugin
 		
 		config.addBooleanParameter2( "MagnetPlugin.dl.position.from.mag.time", "MagnetPlugin.dl.position.from.mag.time", true );
 		
+		storage_folder = config.addDirectoryParameter2( "MagnetPlugin.storage.folder", "MagnetPlugin.storage.folder", getDefaultStorageDir().getAbsolutePath());
+		
 		Parameter[] nps = new Parameter[ AENetworkClassifier.AT_NETWORKS.length ];
 
 		for ( int i=0; i<nps.length; i++ ){
@@ -781,7 +786,7 @@ MagnetPlugin
 						if ( instance.getUIType().equals(UIInstance.UIT_SWT) ){
 
 							try{
-								Class.forName("com.biglybt.plugin.magnet.swt.MagnetPluginUISWT").getConstructor(
+								Class.forName("com.biglybt.ui.swt.plugin.magnet.swt.MagnetPluginUISWT").getConstructor(
 									new Class[]{ UIInstance.class, TableContextMenuItem[].class }).newInstance(
 										new Object[]{ instance, menus.toArray( new TableContextMenuItem[menus.size()])} );
 
@@ -990,7 +995,7 @@ MagnetPlugin
 				conc = 1;
 			}
 			
-			ThreadPool tp = new ThreadPool( "Magnet Recovery", conc, true );
+			ThreadPool<AERunnable> tp = new ThreadPool<AERunnable>( "Magnet Recovery", conc, true );
 			
 			List<Map> sorted = new ArrayList<Map>( active.values());
 			
@@ -1025,6 +1030,31 @@ MagnetPlugin
 					
 				byte[]	hash = (byte[])map.get( "hash" );
 				
+				try{
+					Download existing_download = plugin_interface.getDownloadManager().getDownload( hash );
+					
+					if ( existing_download != null ){
+						
+						Debug.outNoStack( "Download '" + existing_download.getName() + "' already present, ignoring magnet recovery" );
+						
+						synchronized( download_activities ){
+							
+							Map temp = COConfigurationManager.getMapParameter( "MagnetPlugin.active.magnets", new HashMap());
+						
+							String hash_str = Base32.encode( hash );
+							
+							temp.remove( hash_str );
+						}
+						
+						COConfigurationManager.setDirty();
+						
+						continue;
+					}
+				}catch( Throwable e ){
+					
+					Debug.out( e );
+				}
+				
 				try{
 
 					active_hashes.add( ByteFormatter.encodeString( hash ));
@@ -1208,11 +1238,9 @@ MagnetPlugin
 		AEThread2.createAndStartDaemon( "MagnetPlugin:mdtidy", ()->{
 			
 			try{
-				File torrents_dir = FileUtil.getUserFile( "torrents" );
-
-				File md_dir = FileUtil.newFile( torrents_dir, "md" );
+				File storage_dir = getStorageDir();
 				
-				File[] files = md_dir.listFiles();
+				File[] files = storage_dir.listFiles();
 				
 				if ( files != null ){
 					
@@ -1241,6 +1269,39 @@ MagnetPlugin
 		});
 	}
 	
+	protected File
+	getDefaultStorageDir()
+	{
+		File torrents_dir = FileUtil.getUserFile( "torrents" );
+
+		File md_dir = FileUtil.newFile( torrents_dir, "md" );
+		
+		if ( !md_dir.exists()){
+			
+			FileUtil.mkdirs( md_dir );
+		}
+		
+		return( md_dir );
+	}
+	
+	protected File
+	getStorageDir()
+	{
+		File dir = new File( storage_folder.getValue());
+		
+		if ( !dir.exists()){
+			
+			dir.mkdirs();
+			
+			if ( !dir.exists()){
+				
+				dir = getDefaultStorageDir();
+			}
+		}
+		
+		return( dir );
+	}
+	
 	private void
 	updateRecoverableDownloads()
 	{
