@@ -258,9 +258,9 @@ MagnetPluginMDDownloader
 		
 					setup_started = true;
 	
-					File torrents_dir = FileUtil.getUserFile( "torrents" );
-		
-					md_dir = FileUtil.newFile( torrents_dir, "md", hash_str );
+					File storage_dir = plugin.getStorageDir();
+							
+					md_dir = FileUtil.newFile( storage_dir, hash_str );
 					
 					if ( !md_dir.exists()){
 						
@@ -385,6 +385,17 @@ MagnetPluginMDDownloader
 		
 					TorrentUtils.setFlag( meta_torrent, TorrentUtils.TORRENT_FLAG_LOW_NOISE, true );
 	
+					Map<String,Object> debug_data = new HashMap<>();
+					
+					debug_data.put( "args", args );
+					
+					if ( initial_metadata != null ){
+						
+						debug_data.put( "im", initial_metadata );
+					}
+					
+					meta_torrent.setAdditionalMapProperty( "metadata_download_debug", debug_data);
+					
 					meta_torrent.serialiseToBEncodedFile( torrent_file );
 		
 					download_manager.clearNonPersistentDownloadState( hash );
