@@ -1,17 +1,16 @@
 /*
- * Created on Oct 9, 2009
- * Created by Paul Gardner
- *
- * Copyright (C) Azureus Software, Inc, All Rights Reserved.
+ * Copyright (C) Bigly Software.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -36,6 +35,8 @@ import com.biglybt.core.disk.DiskManagerFileInfoSet;
 import com.biglybt.core.download.DownloadManager;
 import com.biglybt.core.download.DownloadManagerState;
 import com.biglybt.core.global.GlobalManager;
+import com.biglybt.core.history.DownloadHistory;
+import com.biglybt.core.history.DownloadHistoryManager;
 import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.logging.LogAlert;
 import com.biglybt.core.logging.Logger;
@@ -56,6 +57,8 @@ import com.biglybt.core.util.*;
 import com.biglybt.pif.PluginException;
 import com.biglybt.pif.PluginInterface;
 import com.biglybt.pif.download.Download;
+import com.biglybt.pif.download.DownloadStub;
+import com.biglybt.pif.download.DownloadStub.DownloadStubEx;
 import com.biglybt.pif.ipc.IPCException;
 import com.biglybt.pif.logging.LoggerChannel;
 import com.biglybt.pif.torrent.Torrent;
@@ -469,6 +472,158 @@ SimpleAPIPlugin
 				}
 				
 				return( JSONUtils.encodeToJSON( json ));
+			
+			}else if ( method.equals( "listdownloadhistory" )){
+				
+				JSONArray json = new JSONArray();
+				
+				com.biglybt.pif.download.DownloadManager download_manager = CoreFactory.getSingleton().getPluginManager().getDefaultPluginInterface().getDownloadManager();
+				
+				DownloadHistoryManager dh_manager =
+						(DownloadHistoryManager) CoreFactory.getSingleton().getGlobalManager().getDownloadHistoryManager();
+				
+				List<DownloadHistory> history = dh_manager.getHistory();			
+				
+				Collections.sort( history, (h1,h2)->Long.compare(h2.getAddTime(),h1.getAddTime()));
+				
+				for ( DownloadHistory dh: history ){
+					
+					try{
+						JSONObject	obj = new JSONObject();
+						
+						obj.put( "DisplayName", dh.getName());
+						
+						byte[] hash = dh.getTorrentHash();
+						
+						obj.put( "InfoHash", hash==null?"":ByteFormatter.encodeString( hash ));
+						
+						String save_path = dh.getSaveLocation();
+						
+						obj.put( "SavePath", save_path );
+						
+						obj.put( "AddTime", dh.getAddTime());
+						obj.put( "CompleteTime", dh.getCompleteTime());
+						obj.put( "RemoveTime", dh.getRemoveTime());
+						
+						long archive_time = 0;
+						
+						if ( hash != null ){
+						
+							DownloadStub stub = download_manager.lookupDownloadStub( hash );
+							
+							if ( stub instanceof DownloadStubEx ){
+								
+								archive_time = ((DownloadStubEx)stub).getCreationDate();
+							}
+						}
+						
+						obj.put( "ArchiveTime", archive_time );
+						
+						obj.put( "Size", dh.getSize());
+						
+						try{
+							String[] tags = dh.getTags();
+							
+							JSONArray tags_a = new JSONArray();
+							
+							for ( String t: tags ){
+								
+								tags_a.add( t );
+							}
+							
+							obj.put( "Tags", tags_a );
+							
+						}catch( Throwable e ){
+							
+							Debug.out( e );
+						}
+						
+						json.add( obj );
+						
+					}catch( Throwable e ){
+						
+						Debug.out( e );
+					}
+				}
+				
+				if ( response != null ){
+					
+					response.setContentType( "application/json; charset=UTF-8" );
+				}
+				
+				return( JSONUtils.encodeToJSON( json ));
+				
+			}else if ( method.equals( "listarchiveddownloads" )){
+				
+				JSONArray json = new JSONArray();
+				
+				com.biglybt.pif.download.DownloadManager download_manager = CoreFactory.getSingleton().getPluginManager().getDefaultPluginInterface().getDownloadManager();
+				
+				DownloadStub[] temp = download_manager.getDownloadStubs();
+				
+				List<DownloadStubEx> stubs = new ArrayList<>( temp.length );
+				
+				for ( DownloadStub ds: temp ){
+					
+					if( ds instanceof DownloadStubEx ){
+						
+						stubs.add((DownloadStubEx)ds);
+					}
+				}
+				
+				Collections.sort( stubs, (h1,h2)->Long.compare(h2.getCreationDate(),h1.getCreationDate()));
+				
+				for ( DownloadStubEx ds: stubs ){
+					
+					try{
+						JSONObject	obj = new JSONObject();
+						
+						obj.put( "DisplayName", ds.getName());
+						
+						byte[] hash = ds.getTorrentHash();
+						
+						obj.put( "InfoHash", hash==null?"":ByteFormatter.encodeString( hash ));
+						
+						String save_path = ds.getSavePath();
+						
+						obj.put( "SavePath", save_path );
+						
+						obj.put( "AddTime", ds.getCreationDate());
+						obj.put( "CompleteTime", ds.getCompletionDate());
+						
+						obj.put( "Size", ds.getTorrentSize());
+						
+						try{
+							String[] tags = ds.getManualTags();
+							
+							JSONArray tags_a = new JSONArray();
+							
+							for ( String t: tags ){
+								
+								tags_a.add( t );
+							}
+							
+							obj.put( "Tags", tags_a );
+							
+						}catch( Throwable e ){
+							
+							Debug.out( e );
+						}
+						
+						json.add( obj );
+						
+					}catch( Throwable e ){
+						
+						Debug.out( e );
+					}
+				}
+				
+				if ( response != null ){
+					
+					response.setContentType( "application/json; charset=UTF-8" );
+				}
+				
+				return( JSONUtils.encodeToJSON( json ));
 				
 			}else if ( method.equals( "listfiles" )){
 				
@@ -994,7 +1149,14 @@ SimpleAPIPlugin
 				}
 			}else if ( method.equals( "alert" )){
 				
-				DownloadManager dm = getDownloadFromHash( args );
+				DownloadManager dm = null;
+				
+				try{
+					dm = getDownloadFromHash( args );
+					
+				}catch( Throwable e ){
+					
+				}
 
 				String caption	= args.get( "caption" );
 				
@@ -1022,13 +1184,23 @@ SimpleAPIPlugin
 				
 				LogAlert alert = new LogAlert( LogAlert.REPEATABLE, atype, caption );
 				
-				alert.details = dm.getDisplayName();
+				if ( dm != null ){
+				
+					alert.details = dm.getDisplayName();
+				}
 				
 				String details	= args.get( "details" );
 
 				if ( details != null && !details.isEmpty()){
 					
-					alert.details += "\n\n" + details;
+					if ( dm != null ){
+					
+						alert.details += "\n\n" + details;
+					
+					}else{
+					
+						alert.details = details;
+					}
 				}
 				
 				alert.isNative = true;
