@@ -187,6 +187,7 @@ UPnPPlugin
 			// UPNP
 
 		upnp_config.addLabelParameter2( "upnp.info" );
+		upnp_config.addLabelParameter2( "upnp.info.ipv4" );
 		upnp_config.addHyperlinkParameter2("upnp.wiki_link", Constants.URL_WIKI + "w/UPnP");
 
 
@@ -803,7 +804,7 @@ UPnPPlugin
 
 					if ( !include ){
 
-						logNoRepeat( USN, "Device '" + location + "' is being ignored as excluded in address list" );
+						logNoRepeat( USN, "Device '" + location + "' is being ignored as excluded in address list", "" );
 
 						return( false );
 					}
@@ -821,7 +822,7 @@ UPnPPlugin
 					// if all exclude then we let others through
 				}else{
 
-					logNoRepeat( USN, "Device '" + location + "' is being ignored as not in address list" );
+					logNoRepeat( USN, "Device '" + location + "' is being ignored as not in address list", "" );
 
 					return( false );
 				}
@@ -846,12 +847,12 @@ UPnPPlugin
 
 		if ( !ok ){
 
-			logNoRepeat( USN, "Device '" + location + "' is being ignored: " + stats );
+			logNoRepeat( USN, "Device '" + location + "' is being ignored: ", stats );
 
 		}else{
 
 
-			logNoRepeat( USN, "Device '" + location +"' is ok: " + stats );
+			logNoRepeat( USN, "Device '" + location +"' is ok: ", stats );
 		}
 
 		return( ok );
@@ -860,7 +861,8 @@ UPnPPlugin
 	protected void
 	logNoRepeat(
 		String	usn,
-		String	msg )
+		String	msg,
+		String 	suffix )
 	{
 		synchronized( log_no_repeat_map ){
 
@@ -874,7 +876,7 @@ UPnPPlugin
 			log_no_repeat_map.put( usn, msg );
 		}
 
-		log.log( msg );
+		log.log( msg + suffix );
 	}
 
 	@Override
