@@ -83,6 +83,7 @@ WebPlugin
 	public static final String	PR_ENABLE_I2P				= "EnableI2P";					// Boolean
 	public static final String	PR_ENABLE_TOR				= "EnableTor";					// Boolean
 	public static final String	PR_ENABLE_UPNP				= "EnableUPNP";					// Boolean
+	public static final String	PR_REVERSE_PROXY			= "ReverseProxy";				// Boolean
 
 	public static final String	PROPERTIES_MIGRATED		= "Properties Migrated";
 	//public static final String	CONFIG_MIGRATED			= "Config Migrated";
@@ -125,6 +126,9 @@ WebPlugin
 	public static final String	CONFIG_UPNP_ENABLE				= "UPnP Enable";
 	public 				boolean	CONFIG_UPNP_ENABLE_DEFAULT		= true;
 
+	public static final String	CONFIG_REVERSE_PROXY			= "Reverse Proxy";
+	public 				boolean	CONFIG_REVERSE_PROXY_DEFAULT	= false;
+	
 	public static final String 	CONFIG_HOME_PAGE				= PR_HOME_PAGE;
 	public  		 String 	CONFIG_HOME_PAGE_DEFAULT		= "index.html";
 
@@ -171,6 +175,7 @@ WebPlugin
 	private InfoParameter			param_tor_dest;
 
 	private BooleanParameter		p_upnp_enable;
+	private BooleanParameter		p_reverse_proxy;
 
 	private BooleanParameter		pw_enable;
 	private StringParameter			p_user_name;
@@ -312,6 +317,13 @@ WebPlugin
 			CONFIG_UPNP_ENABLE_DEFAULT	= pr_enable_upnp.booleanValue();
 		}
 
+		Boolean	pr_reverse_proxy = (Boolean)properties.get(PR_REVERSE_PROXY);
+
+		if ( pr_reverse_proxy != null ){
+
+			CONFIG_REVERSE_PROXY_DEFAULT = pr_reverse_proxy.booleanValue();
+		}
+		
 		Boolean	pr_hide_resource_config = (Boolean)properties.get( PR_HIDE_RESOURCE_CONFIG );
 
 		log = (LoggerChannel)properties.get( PR_LOG );
@@ -583,17 +595,17 @@ WebPlugin
 							"webui.upnpenable",
 							CONFIG_UPNP_ENABLE_DEFAULT );
 
-		p_upnp_enable.addListener(
-			new ParameterListener()
-			{
-				@Override
-				public void
-				parameterChanged(
-					Parameter param )
-				{
-					setupUPnP();
-				}
-			});
+		p_upnp_enable.addListener((p)->setupUPnP());
+			
+		p_reverse_proxy =
+				config_model.addBooleanParameter2(
+								CONFIG_REVERSE_PROXY,
+								"webui.reverse.proxy",
+								CONFIG_REVERSE_PROXY_DEFAULT );
+	
+		p_reverse_proxy.setMinimumRequiredUserMode( Parameter.MODE_INTERMEDIATE );
+		
+		p_reverse_proxy.addListener( update_server_listener );
 
 		plugin_interface.addListener(
 				new PluginListener()
@@ -703,7 +715,7 @@ WebPlugin
 		config_model.createGroup(
 			"ConfigView.section.server",
 			new Parameter[]{
-				param_port, param_bind, param_protocol, param_i2p_dest, param_tor_dest, p_upnp_enable,
+				param_port, param_bind, param_protocol, param_i2p_dest, param_tor_dest, p_upnp_enable, p_reverse_proxy,
 			});
 
 		param_home 		= config_model.addStringParameter2(	CONFIG_HOME_PAGE, "webui.homepage", CONFIG_HOME_PAGE_DEFAULT );
@@ -1381,6 +1393,20 @@ WebPlugin
 				}
 			}
 
+			Map<String,Object>		tc_properties = new HashMap<>();
+
+			Boolean prop_non_blocking = (Boolean)properties.get( PR_NON_BLOCKING );
+
+			if ( prop_non_blocking != null && prop_non_blocking ){
+
+				tc_properties.put( Tracker.PR_NON_BLOCKING, true );
+			}
+			
+			if ( p_reverse_proxy.getValue()){
+					
+				tc_properties.put( Tracker.PR_REVERSE_PROXY, true );
+			}
+			
 			if ( tracker_context != null ){
 
 				URL	url = tracker_context.getURLs()[0];
@@ -1389,9 +1415,12 @@ WebPlugin
 				int			existing_port		= url.getPort()==-1?url.getDefaultPort():url.getPort();
 				InetAddress existing_bind_ip 	= tracker_context.getBindIP();
 
+				Map<String,Object> existing_properties = tracker_context.getProperties();
+				
 				if ( 	( existing_port == requested_port || requested_port == 0 ) &&
 						existing_protocol.equalsIgnoreCase( protocol_str ) &&
-						sameAddress( bind_ip, existing_bind_ip )){
+						sameAddress( bind_ip, existing_bind_ip ) && 
+						tc_properties.equals( existing_properties )){
 
 					return;
 				}
@@ -1403,21 +1432,13 @@ WebPlugin
 
 			int	protocol = protocol_str.equalsIgnoreCase( "HTTP")?Tracker.PR_HTTP:Tracker.PR_HTTPS;
 
-			Map<String,Object>		tc_properties = new HashMap<>();
-
-			Boolean prop_non_blocking = (Boolean)properties.get( PR_NON_BLOCKING );
-
-			if ( prop_non_blocking != null && prop_non_blocking ){
-
-				tc_properties.put( Tracker.PR_NON_BLOCKING, true );
-			}
-
 			log.log( 	LoggerChannel.LT_INFORMATION,
 						"Server initialisation: port=" + requested_port +
 						(bind_ip == null?"":(", bind=" + bind_str + "->" + bind_ip + ")")) +
 						", protocol=" + protocol_str +
 						(root_dir.length()==0?"":(", root=" + root_dir )) +
-						(properties.size()==0?"":(", props=" + properties )));
+						(properties.size()==0?"":(", props=" + properties ))+
+						(tc_properties.size()==0?"":(", tc_props=" + tc_properties )));
 
 			tracker_context =
 				plugin_interface.getTracker().createWebContext(
