@@ -30,6 +30,7 @@ import org.eclipse.swt.widgets.*;
 import com.biglybt.core.internat.MessageText;
 import com.biglybt.core.util.TrackersUtil;
 import com.biglybt.ui.swt.Messages;
+import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.wizard.AbstractWizardPanel;
 import com.biglybt.ui.swt.wizard.IWizardPanel;
 
@@ -139,7 +140,7 @@ public class MultiTrackerPanel extends AbstractWizardPanel<NewTorrentWizard> imp
         setEditDeleteEnable();
       }
     });
-    final Label labelSeparator = new Label(panel,SWT.SEPARATOR | SWT.HORIZONTAL);
+    Control labelSeparator = Utils.createSkinnedLabelSeparator(panel, SWT.HORIZONTAL);
     gridData = new GridData(GridData.FILL_HORIZONTAL);
     gridData.horizontalSpan = 3;
     labelSeparator.setLayoutData(gridData);
