@@ -50,9 +50,7 @@ import com.biglybt.core.util.*;
 import com.biglybt.ui.common.util.MenuItemManager;
 import com.biglybt.ui.common.viewtitleinfo.ViewTitleInfo;
 import com.biglybt.ui.mdi.MdiEntry;
-import com.biglybt.ui.mdi.MultipleDocumentInterface;
 import com.biglybt.ui.swt.MenuBuildUtils;
-import com.biglybt.ui.swt.UIFunctionsManagerSWT;
 import com.biglybt.ui.swt.MenuBuildUtils.MenuBuilder;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.debug.ObfuscateImage;
@@ -64,12 +62,13 @@ import com.biglybt.ui.swt.pif.UISWTViewEventListener;
 import com.biglybt.ui.swt.pifimpl.UISWTViewBuilderCore;
 import com.biglybt.ui.swt.pifimpl.UISWTViewCore;
 import com.biglybt.ui.swt.pifimpl.UISWTViewEventCancelledException;
+import com.biglybt.ui.swt.shells.PopOutManager;
 import com.biglybt.ui.swt.shells.main.MainMDISetup;
 import com.biglybt.ui.swt.skin.*;
 import com.biglybt.ui.swt.utils.ColorCache;
 import com.biglybt.ui.swt.views.IViewAlwaysInitialize;
 import com.biglybt.ui.swt.views.ViewManagerSWT;
-import com.biglybt.ui.swt.views.skin.SkinnedDialog;
+import com.biglybt.ui.swt.widgets.TabFolderRenderer;
 import com.biglybt.util.DataSourceUtils;
 
 import com.biglybt.pif.PluginInterface;
@@ -89,8 +88,9 @@ public class TabbedMDI
 {
 	private static final String KEY_AUTO_CLOSE = "TabbedMDI:autoclose";
 	
-	private CTabFolder tabFolder;
-
+	private CTabFolder			tabFolder;
+	private TabFolderRenderer	tabFolderRenderer;
+	
 	private LinkedList<TabbedEntry>	select_history = new LinkedList<>();
 
 	protected boolean minimized;
@@ -218,6 +218,20 @@ public class TabbedMDI
 					| SWT.BORDER | SWT.CLOSE);
 		}
 
+		tabFolderRenderer = 
+			new TabFolderRenderer(
+				tabFolder, 
+				new TabFolderRenderer.Adapter(){
+					
+					@Override
+					public TabbedEntry 
+					getTabbedEntryFromTabItem(
+						CTabItem item)
+					{
+						return( getEntryFromTabItem(item));
+					}
+				});
+		
 		iFolderHeightAdj = tabFolder.computeSize(SWT.DEFAULT, 0).y;
 
 		if (isMainMDI) {
@@ -235,7 +249,7 @@ public class TabbedMDI
 			};
 			COConfigurationManager.addAndFireParameterListener("GUI_SWT_bFancyTab",
 					paramFancyTabListener);
-  		tabFolder.setSimple(!COConfigurationManager.getBooleanParameter("GUI_SWT_bFancyTab"));
+			tabFolder.setSimple(!COConfigurationManager.getBooleanParameter("GUI_SWT_bFancyTab"));
 		} else {
 			tabFolder.setSimple(true);
 			tabFolder.setMaximizeVisible(maximizeVisible);
@@ -251,18 +265,22 @@ public class TabbedMDI
 
 		hsb = tabFolder.getForeground().getRGB().getHSB();
 		hsb[2] *= (Constants.isOSX) ? 1.1 : 0.03;
-		tabFolder.setForeground(ColorCache.getColor(display, hsb));
-
-		tabFolder.setSelectionBackground(new Color[] {
-			Colors.getSystemColor(display, SWT.COLOR_LIST_BACKGROUND),
-			Colors.getSystemColor(display, SWT.COLOR_LIST_BACKGROUND),
-			Colors.getSystemColor(display, SWT.COLOR_WIDGET_BACKGROUND)
-		}, new int[] {
-			10,
-			90
-		}, true);
-		tabFolder.setSelectionForeground(Colors.getSystemColor(display, SWT.COLOR_LIST_FOREGROUND));
+		
+		if ( !Utils.isDarkAppearanceNativeWindows()){
 
+			tabFolder.setForeground(ColorCache.getColor(display, hsb));
+	
+			tabFolder.setSelectionBackground(new Color[] {
+				Colors.getSystemColor(display, SWT.COLOR_LIST_BACKGROUND),
+				Colors.getSystemColor(display, SWT.COLOR_LIST_BACKGROUND),
+				Colors.getSystemColor(display, SWT.COLOR_WIDGET_BACKGROUND)
+			}, new int[] {
+				10,
+				90
+			}, true);
+			tabFolder.setSelectionForeground(Colors.getSystemColor(display, SWT.COLOR_LIST_FOREGROUND));
+		}
+		
 		if (minimumCharacters > 0) {
 			tabFolder.setMinimumCharacters(minimumCharacters);
 		}
@@ -644,10 +662,6 @@ public class TabbedMDI
 			}
 		});
 
-		if (SWT.getVersion() > 3600) {
-			TabbedMDI_Ren.setupTabFolderRenderer(this, tabFolder);
-		}
-
 		if (minimizeVisible) {
 			boolean toMinimize = ConfigurationManager.getInstance().getBooleanParameter(props_prefix + ".subViews.minimized");
 			setMinimized(toMinimize);
@@ -1487,6 +1501,12 @@ public class TabbedMDI
 		});
 	}
 
+	public TabFolderRenderer
+	getRenderer()
+	{
+		return( tabFolderRenderer );
+	}
+	
 	@Override
 	public int getFolderHeight() {
 		return iFolderHeightAdj;
@@ -1647,6 +1667,27 @@ public class TabbedMDI
 					}
 				});
 				
+				MenuItem menuItemTopbar = menuManager.addMenuItem( menuParentItem, "label.topbar");
+				
+				menuItemTopbar.addListener(new MenuItemListener() {
+					@Override
+					public void selected(com.biglybt.pif.ui.menus.MenuItem menu, Object data ) {
+							
+						TabbedEntry	target = entry;
+						
+						if ( data instanceof Object[]) {
+							Object[] odata = (Object[])data;
+							if ( odata.length == 1 && odata[0] instanceof TabbedEntry ) {
+								target = (TabbedEntry)odata[0];
+							}
+						}else if ( data instanceof TabbedEntry ){
+							target = (TabbedEntry)data;
+						}
+						
+						MainMDISetup.getSb_dashboard().addItemToTopbar( target );
+					}
+				});
+				
 				MenuItem menuItemSidebar = menuManager.addMenuItem( menuParentItem, "label.sidebar");
 				
 				menuItemSidebar.addListener(new MenuItemListener() {
@@ -1733,7 +1774,7 @@ public class TabbedMDI
 						target = (TabbedEntry)data;
 					}
 
-					popoutEntry( target, menu==menuItemOnTop );
+					popoutEntry( target, menu==menuItemOnTop?PopOutManager.OPT_MAP_ON_TOP:PopOutManager.OPT_MAP_NONE );
 				}
 			};
 			
@@ -1744,58 +1785,10 @@ public class TabbedMDI
 	
 	public boolean
 	popoutEntry(
-		MdiEntry	_entry,
-		boolean		onTop )
+		MdiEntry			entry,
+		Map<String,Object>	options )
 	{
-		TabbedEntry	target = (TabbedEntry)_entry;
-		
-		SkinnedDialog skinnedDialog =
-				new SkinnedDialog(
-						"skin3_dlg_sidebar_popout",
-						"shell",
-						onTop?UIFunctionsManagerSWT.getUIFunctionsSWT().getMainShell():null,
-						SWT.RESIZE | SWT.MAX | SWT.DIALOG_TRIM);
-
-		SWTSkin skin = skinnedDialog.getSkin();
-
-		SWTSkinObjectContainer cont = target.buildStandAlone((SWTSkinObjectContainer)skin.getSkinObject( "content-area" ));
-
-		if ( cont != null ){
-
-			String ds_str = "";
-			Object ds = target.getDatasourceCore();
-			DownloadManager dm = DataSourceUtils.getDM(ds);
-
-			if (dm != null) {
-				ds_str = dm.getDisplayName();
-			}
-
-			skinnedDialog.setTitle( target.getTitle() + (ds_str.length()==0?"":(" - " + ds_str )));
-
-			
-			String metrics_id;
-			
-				// hack - we don't want to remember shell metrics on a per-download basis
-			
-			if ( target.getDatasource() instanceof Download ){
-				
-				metrics_id = MultipleDocumentInterface.SIDEBAR_SECTION_TORRENT_DETAILS;
-				
-			}else{
-				
-				metrics_id = target.getId();
-			}
-		
-			skinnedDialog.open( "mdi.popout:" + metrics_id, true );
-
-			return( true );
-			
-		}else{
-
-			skinnedDialog.close();
-			
-			return( false );
-		}
+		return( PopOutManager.popOut((TabbedEntry)entry,options));
 	}
 	
 	@Override
@@ -1892,34 +1885,7 @@ public class TabbedMDI
 
 			Utils.addSafeMouseUpListener(label, event -> {
 				// From TabbedMDI.addMenus, but there's also Sidebar.addGeneralMenus which doesn't set datasource
-				SkinnedDialog skinnedDialog = new SkinnedDialog(
-						"skin3_dlg_sidebar_popout", "shell", null, // standalone
-						SWT.RESIZE | SWT.MAX | SWT.DIALOG_TRIM);
-
-				SWTSkin skin = skinnedDialog.getSkin();
-
-				SWTSkinObjectContainer cont = ((UISWTViewCore) parentView).buildStandAlone(
-						(SWTSkinObjectContainer) skin.getSkinObject("content-area"));
-
-				if (cont != null) {
-
-					String ds_str = "";
-					Object ds = parentView.getDataSource();
-					DownloadManager dm = DataSourceUtils.getDM(ds);
-
-					if (dm != null) {
-						ds_str = dm.getDisplayName();
-					}
-
-					skinnedDialog.setTitle(((UISWTViewCore) parentView).getFullTitle()
-							+ (ds_str.length() == 0 ? "" : (" - " + ds_str)));
-
-					skinnedDialog.open( "mdi.popout:" + currentEntry.getId(), true );
-
-				} else {
-
-					skinnedDialog.close();
-				}
+				PopOutManager.popOut(parentView,currentEntry);
 			});
 		}
 
