@@ -24,6 +24,7 @@ import com.biglybt.core.CoreFactory;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Supplier;
 
 import org.eclipse.swt.SWT;
@@ -43,11 +44,13 @@ import com.biglybt.core.util.AEThread2;
 import com.biglybt.core.util.Debug;
 import com.biglybt.core.util.DelayedEvent;
 import com.biglybt.core.util.SystemTime;
+import com.biglybt.core.util.ThreadPool;
 import com.biglybt.ui.swt.UIExitUtilsSWT;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.UIExitUtilsSWT.canCloseListener;
 import com.biglybt.ui.swt.mainwindow.Colors;
 import com.biglybt.ui.swt.shells.MessageBoxShell;
+import com.biglybt.ui.swt.shells.opentorrent.OpenTorrentOptionsWindow;
 import com.biglybt.core.CoreOperation;
 import com.biglybt.core.CoreOperationListener;
 import com.biglybt.core.CoreOperationTask;
@@ -60,6 +63,10 @@ ProgressWindow
 {
 	private static canCloseListener canCloseListener;
 	
+	private static final AtomicInteger	window_id_next = new AtomicInteger();
+
+	private static List<ProgressWindow>	active_windows = new ArrayList();
+	
 	public static void
 	register(
 		Core core )
@@ -77,6 +84,11 @@ ProgressWindow
 						
 						for ( CoreOperation op: ops ){
 							
+							if ( op.isRemoved()){
+								
+								continue;
+							}
+							
 							int type = op.getOperationType();
 							
 							if (	type == CoreOperation.OP_DOWNLOAD_CHECKING ||
@@ -85,9 +97,21 @@ ProgressWindow
 									type == CoreOperation.OP_FILE_MOVE ){
 								
 								CoreOperationTask task = op.getTask();
-								
+															
 								if ( task != null ){
 						
+									ProgressCallback cb = task.getProgressCallback();
+
+									if ( cb != null ){
+										
+										int state = cb.getTaskState();
+										
+										if ( state == ProgressCallback.ST_CANCEL ){
+											
+											continue;
+										}
+									}
+									
 									if ( active.length() > 128 ){
 										
 										active += ", ...";
@@ -218,10 +242,14 @@ ProgressWindow
 						
 						if ( task != null ){
 
-							if ( 	type ==  CoreOperation.OP_FILE_MOVE && 
-									COConfigurationManager.getBooleanParameter("Suppress File Move Dialog" )){
+								// if someone kicks off a batch move with loads of affected downloads (for example) we can end up 
+								// stack-overflowing in the ProgressWindow as it runs a dispatch loop.
+							
+							if ( 	( Utils.getDispatchLoopDepth() > 20 ) ||
+									(	type ==  CoreOperation.OP_FILE_MOVE && 
+										COConfigurationManager.getBooleanParameter("Suppress File Move Dialog" ))){
 
-								AEThread2.createAndStartDaemon( "Core Operation", ()->{
+								core_op_pool.run( AERunnable.create(()->{
 									
 									try{
 										task.run( operation );
@@ -230,7 +258,7 @@ ProgressWindow
 										
 										core.removeOperation( operation );
 									}
-								});
+								}));
 								
 							}else{
 								
@@ -266,6 +294,10 @@ ProgressWindow
 		UIExitUtilsSWT.removeListener(canCloseListener);
 	}
 	
+    private static final ThreadPool	core_op_pool = new ThreadPool( "ProgressWindow:coreops", 32, true );
+	
+	private final int window_id = window_id_next.incrementAndGet();
+
 	private volatile Shell 			shell;
 	private volatile boolean 		task_complete;
 
@@ -500,6 +532,12 @@ ProgressWindow
 		}
 	}
 
+	private Shell
+	getShell()
+	{
+		return( shell );
+	}
+	
 	protected void
 	showDialog(
 		Shell			_shell,
@@ -896,7 +934,69 @@ ProgressWindow
 			}
 		}
 		
-		shell.open();
+		ProgressWindow moveBelow = null;
+		
+		for ( ProgressWindow window: active_windows ){
+			
+			if ( 	moveBelow == null || 
+					moveBelow.window_id < window.window_id ){
+				
+				moveBelow = window;
+			}
+		}
+		
+		active_windows.add( this );
+		
+		shell.addListener( SWT.Dispose, (ev)->{ active_windows.remove( this ); });
+
+		if ( moveBelow == null ){
+			
+			shell.open();
+			
+		}else{
+			
+			shell.moveBelow(moveBelow.getShell());
+
+			shell.setVisible(true);
+		}
+		
+			// don't want them appearing on top of each other
+
+		int	num_active_windows = active_windows.size();
+
+		if ( num_active_windows > 1 ){
+
+			int	max_x = Integer.MIN_VALUE;
+			int max_y = Integer.MIN_VALUE;
+
+			for ( ProgressWindow window: active_windows ){
+						
+				Rectangle rect = window.getShell().getBounds();
+
+				max_x = Math.max( max_x, rect.x );
+				max_y = Math.max( max_y, rect.y );
+			}
+
+			if ( max_x > Integer.MIN_VALUE ){
+				
+				Rectangle rect = shell.getBounds();
+
+				rect.x = max_x + 16;
+				rect.y = max_y + 16;
+
+				try{
+					Utils.setShellMetricsConfigEnabled( shell, false );
+				
+					shell.setBounds( rect );
+					
+				}finally{
+					
+					Utils.setShellMetricsConfigEnabled( shell, true );
+				}
+			}
+		}
+
+		Utils.verifyShellRect( shell, true );
 	}
 
 	public void
