@@ -46,6 +46,8 @@ SBC_SearchResult
 	private final String			seeds_peers;
 	private final long				seeds_peers_sort;
 	private final int				seed_count;
+	private final int				peer_count;
+	private final int				completed_count;
 	private final long				votes_comments_sort;
 	private final String			votes_comments;
 
@@ -88,6 +90,7 @@ SBC_SearchResult
 		}
 		
 		seed_count = seeds<0?0:seeds;
+		peer_count = leechers<0?0:leechers;
 		
 		seeds_peers = (seeds<0?"--":String.valueOf(seeds)) + "/" + (leechers<0?"--":String.valueOf(leechers));
 
@@ -105,6 +108,8 @@ SBC_SearchResult
 
 		seeds_peers_sort = ((seeds&0x7fffffff)<<32) | ( leechers & 0xffffffff );
 
+		completed_count = result.getNbCompleted();
+		
 		long votes		= result.getVotes();
 		long comments 	= result.getComments();
 
@@ -187,6 +192,13 @@ SBC_SearchResult
 		return( seed_count );
 	}
 	
+	@Override
+	public int 
+	getNbPeers()
+	{
+		return( peer_count );
+	}
+	
 	@Override
 	public String
 	getSeedsPeers()
@@ -201,6 +213,13 @@ SBC_SearchResult
 		return( seeds_peers_sort );
 	}
 
+	@Override
+	public int 
+	getNbCompleted() 
+	{
+		return( completed_count );
+	}
+	
 	@Override
 	public String
 	getVotesComments()
