@@ -1009,6 +1009,39 @@ SBC_SearchResultsView
 					}
 				});
 
+		tableManager.registerColumn(
+			SBC_SearchResult.class,
+			ColumnSearchSubResultSeeds.COLUMN_ID,
+				new TableColumnCreationListener() {
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultSeeds(column);
+					}
+				});
+
+		tableManager.registerColumn(
+			SBC_SearchResult.class,
+			ColumnSearchSubResultPeers.COLUMN_ID,
+				new TableColumnCreationListener() {
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultPeers(column);
+					}
+				});
+
+		tableManager.registerColumn(
+			SBC_SearchResult.class,
+			ColumnSearchSubResultGrabbed.COLUMN_ID,
+				new TableColumnCreationListener() {
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultGrabbed(column);
+					}
+				});
+		
 		tableManager.registerColumn(
 			SBC_SearchResult.class,
 			ColumnSearchSubResultRatings.COLUMN_ID,
@@ -1226,6 +1259,8 @@ SBC_SearchResultsView
 			tooltip += MessageText.getString("column.filter.tt.line2");
 
 			bubbleTextBox.setTooltip( tooltip );
+						
+			bubbleTextBox.setMessage( MessageText.getString( "Button.search2" ) );
 		}
 
 		tv_subs_results.setRowDefaultHeight(COConfigurationManager.getIntParameter( "Search Subs Row Height" ));
@@ -1341,11 +1376,16 @@ SBC_SearchResultsView
 
 							for ( SBC_SearchResult result: results ){
 
-								if ( buffer.length() > 0 ){
-									buffer.append( "\r\n" );
-								}
+								byte[] hash = result.getHash();
 
-								buffer.append( getDownloadURI( result ));
+								if ( hash != null && hash.length > 0 ){
+								
+									if ( buffer.length() > 0 ){
+										buffer.append( "\r\n" );
+									}
+	
+									buffer.append( getDownloadURI( result ));
+								}
 							}
 							ClipboardCopy.copyToClipBoard( buffer.toString());
 						}
