@@ -73,6 +73,8 @@ import com.biglybt.ui.swt.pifimpl.UISWTInstanceImpl;
 import com.biglybt.ui.swt.pifimpl.UISWTViewBuilderCore;
 import com.biglybt.ui.swt.pifimpl.UIToolBarManagerImpl;
 import com.biglybt.ui.swt.plugininstall.SimplePluginInstaller;
+import com.biglybt.ui.swt.progress.IProgressReporter;
+import com.biglybt.ui.swt.progress.ProgressReportingManager;
 import com.biglybt.ui.swt.search.SearchHandler;
 import com.biglybt.ui.swt.shells.*;
 import com.biglybt.ui.swt.shells.opentorrent.OpenTorrentOptionsWindow;
@@ -214,7 +216,7 @@ public class UIFunctionsImpl
 
 			if (success) {
 
-				sem.reserve( 30*1000 );	// shouldn't block as if this is SWT thread code will run immediately, otherwise SWT thread shoudl be quick
+				sem.reserve( 30*1000 );	// shouldn't block as if this is SWT thread code will run immediately, otherwise SWT thread should be quick
 			}
 
 			return( result[0] );
@@ -353,6 +355,63 @@ public class UIFunctionsImpl
 		});
 	}
 
+	@Override
+	public Object 
+	pushStatusText(
+		String key )
+	{
+		IProgressReporter pReporter = ProgressReportingManager.getInstance().addReporter();
+		
+		pReporter.setName( key );
+		
+		pReporter.setTitle(MessageText.getString("fileDownloadWindow.title"));
+		
+		return( pReporter );
+	}
+
+	@Override
+	public void 
+	popStatusText(
+		Object	o,
+		int		reason,
+		String	message )
+	{
+		IProgressReporter pReporter = (IProgressReporter)o;
+			
+		if ( reason == 0 ){
+		
+			if ( message != null ){
+				
+				pReporter.appendDetailMessage(message);
+			}
+			
+			pReporter.setDone();
+			
+		}else if ( reason == 1 ){
+			
+			if ( message != null ){
+				
+				pReporter.appendDetailMessage(message);
+			}
+
+			pReporter.cancel();
+			
+		}else{
+			
+			pReporter.setErrorMessage( message!=null?message:MessageText.getString("fileDownloadWindow.state_error"));
+		}
+		
+		pReporter.dispose();
+		
+		if ( reason == 1 ){
+		
+				// remove if cancelled as not of interest, leave for success/fail so result
+				// remains visible if "auto remove" not enabled
+			
+			ProgressReportingManager.getInstance().remove(pReporter);
+		}
+	}
+	
 	// @see UIFunctionsSWT#getMainStatusBar()
 	@Override
 	public IMainStatusBar getMainStatusBar() {
@@ -1164,6 +1223,9 @@ public class UIFunctionsImpl
 								MessageText.getString("Button.no")
 							}, 1);
 
+						promptSepDL.setRemember("remember:openTorrentWindow.mb.alreadyExists.add.dup", false,
+								MessageText.getString("MessageBoxWindow.nomoreprompting"));
+						
 						promptSepDL.open(result -> {
 							if ( result == 0 ){ // Yes
 
