@@ -209,8 +209,6 @@ SBC_SubscriptionResultsView
 
 				control.setMenu( menu );
 
-				final String menu_key = SubscriptionMDIEntry.setupMenus( ds, null );
-
 				menu.addMenuListener(
 					new MenuListener() {
 
@@ -220,6 +218,8 @@ SBC_SubscriptionResultsView
 								mi.dispose();
 							}
 
+							String menu_key = SubscriptionMDIEntry.setupMenus( ds, null );
+
 							com.biglybt.pif.ui.menus.MenuItem[] menu_items = MenuItemManager.getInstance().getAllAsArray( menu_key );
 
 							MenuBuildUtils.addPluginMenuItems(menu_items, menu, true, true,
@@ -440,6 +440,7 @@ SBC_SubscriptionResultsView
 				lblWithKWImg.setImage( imageLoader.getImage( with?"icon_filter_plus":"icon_filter_minus"));
 
 				final Text textWithKW = new Text(cWithKW, SWT.BORDER);
+				Utils.setTT(textWithKW,MessageText.getString("SubscriptionResults.filter.words.tt" ));
 				textWithKW.setMessage(MessageText.getString(with?"SubscriptionResults.filter.with.words":"SubscriptionResults.filter.without.words"));
 				GridData gd = new GridData();
 				gd.widthHint = 100;
@@ -450,7 +451,7 @@ SBC_SubscriptionResultsView
 
 						@Override
 						public void modifyText(ModifyEvent e) {
-							String text = textWithKW.getText().toLowerCase( Locale.US );
+							String text = textWithKW.getText();
 							String[] bits = text.split( "\\s+");
 
 							Set<String>	temp = new HashSet<>();
@@ -679,26 +680,35 @@ SBC_SubscriptionResultsView
 			if ( ds != null ){
 
 				if ( ds.isUpdateable() ){
+					
 					sep = Utils.createSkinnedLabelSeparator(vFilters, SWT.VERTICAL );
+					
 					sep.setLayoutData(new RowData(-1, sepHeight));
 	
-					final Runnable					f_pFilterUpdater 	= pFilterUpdater;
+					final Runnable	f_pFilterUpdater 	= pFilterUpdater;
 	
 					Button save = new Button( vFilters,SWT.PUSH );
+					
 					save.setText( MessageText.getString( "ConfigView.button.save" ));
+					
 					save.addListener(SWT.Selection, new Listener() {
 						@Override
 						public void handleEvent(Event event) {
 	
-							try{
-								ds_filter.save();
+							Utils.getOffOfSWTThread(()->{
+								
+								try{
+									ds_filter.save();
+									
+								}catch( Throwable e ){
+									
+									Debug.out( e );
 	
-								f_pFilterUpdater.run();
-	
-							}catch( Throwable e ){
-	
-								Debug.out( e );
-							}
+								}finally{
+									
+									Utils.execSWTThread(()->f_pFilterUpdater.run());
+								}
+							});
 						}
 					});
 				}
@@ -909,6 +919,39 @@ SBC_SubscriptionResultsView
 					}
 				});
 
+		tableManager.registerColumn(
+			SubscriptionResultFilterable.class,
+			ColumnSearchSubResultSeeds.COLUMN_ID,
+				new TableColumnCreationListener() {
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultSeeds(column);
+					}
+				});
+
+		tableManager.registerColumn(
+			SubscriptionResultFilterable.class,
+			ColumnSearchSubResultPeers.COLUMN_ID,
+				new TableColumnCreationListener() {
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultPeers(column);
+					}
+				});
+		
+		tableManager.registerColumn(
+			SubscriptionResultFilterable.class,
+			ColumnSearchSubResultGrabbed.COLUMN_ID,
+				new TableColumnCreationListener() {
+
+					@Override
+					public void tableColumnCreated(TableColumn column) {
+						new ColumnSearchSubResultGrabbed(column);
+					}
+				});
+		
 		tableManager.registerColumn(
 			SubscriptionResultFilterable.class,
 			ColumnSearchSubResultRatings.COLUMN_ID,
@@ -1375,6 +1418,8 @@ SBC_SubscriptionResultsView
 			tooltip += MessageText.getString("column.filter.tt.line2");
 
 			bubbleTextBox.setTooltip( tooltip );
+			
+			bubbleTextBox.setMessage( MessageText.getString( "Button.search2" ) );
 		}
 
 		tv_subs_results.setRowDefaultHeight(COConfigurationManager.getIntParameter( "Search Subs Row Height" ));
@@ -1473,7 +1518,7 @@ SBC_SubscriptionResultsView
 							
 						if ( Arrays.equals(((SubscriptionResultFilterable)row.getDataSource()).getHash(), hash )){
 			
-							target = Colors.blues[ Colors.BLUES_MIDLIGHT ];
+							target = Utils.isDarkAppearanceNative()?Colors.faded[Colors.FADED_DARKEST-2]:Colors.blues[ Colors.BLUES_MIDLIGHT ];
 						}
 					}
 					
