@@ -136,7 +136,8 @@ public class FilesView
     new FileWriteSpeedItem(),
     new FileETAItem(),
     new RelocatedItem(),
-    new FileModifiedItem(),
+	  new FileModifiedItem(),
+	  new FileCreationItem(),
     new DownloadNameItem(),
   };
 
@@ -186,7 +187,7 @@ public class FilesView
 		registerPluginViews();
 
 		tv = TableViewFactory.createTableViewSWT(PLUGIN_DS_TYPE,
-				TableManager.TABLE_TORRENT_FILES, getPropertiesPrefix(), basicItems,
+				TableManager.TABLE_TORRENT_FILES, getTextPrefixID(), basicItems,
 				"firstpiece", SWT.MULTI | SWT.FULL_SELECTION | SWT.VIRTUAL);
 		
 		tv.setExpandEnabled( true );
@@ -644,7 +645,7 @@ public class FilesView
 			
 			if ( tree_view ){
 				
-					// have to get all rows, not just visible ones, as changed file might be collasped
+					// have to get all rows, not just visible ones, as changed file might be collapsed
 					// but we still want to update parent state
 				
 				rows = tv.getRowsAndSubRows( true );	
@@ -1516,7 +1517,7 @@ public class FilesView
 	{
 		if ( e.keyCode == SWT.F2 && (e.stateMask & SWT.MODIFIER_MASK) == 0 ){
 			
-			FilesViewMenuUtil.rename(tv, tv.getSelectedDataSources(true), null, true, false,false);
+			FilesViewMenuUtil.rename(tv, tv.getSelectedDataSources(true), null, true, false, false, false);
 			
 			e.doit = false;
 			
