@@ -106,7 +106,9 @@ public class FakeTableCell
 	private Graphic graphic;
 
 	private String text;
-
+	private String textEquiv;
+	private double numericValue = Double.NaN;
+	
 	private Object pluginDataSource;
 
 	private Object tooltip;
@@ -954,6 +956,37 @@ public class FakeTableCell
 		return true;
 	}
 
+	
+	@Override
+	public String 
+	getTextEquivalent()
+	{
+		return( textEquiv );
+	}
+
+	@Override
+	public void 
+	setTextEquivalent( 
+		String str )
+	{
+		textEquiv = str;
+	}
+	  
+	@Override
+	public double 
+	getNumeric()
+	{
+		return( numericValue );
+	}
+	
+	@Override
+	public void 
+	setNumeric(
+		double d)
+	{
+		numericValue = d;
+	}
+	
 	// @see com.biglybt.pif.ui.tables.TableCell#setToolTip(java.lang.Object)
 	@Override
 	public void setToolTip(Object tooltip) {
