@@ -64,7 +64,9 @@ TagsItem
 
 		}else{
 
-			String	value = item.getProperties().get( ShareManager.PR_TAGS );
+			Map<String,String> properties = item.getProperties();
+			
+			String	value = properties==null?null:properties.get( ShareManager.PR_TAGS );
 
 			if ( value == null ){
 				
@@ -81,8 +83,14 @@ TagsItem
 				for ( String bit: bits ){
 					
 					try{
-						tags.add( tag_manager.lookupTagByUID( Long.parseLong( bit )));
-												
+						Tag tag = tag_manager.lookupTagByUID( Long.parseLong( bit ));
+						
+							// might have been deleted
+						
+						if ( tag != null ){
+						
+							tags.add( tag );
+						}					
 					}catch( Throwable e ){
 						
 					}
