@@ -36,6 +36,7 @@ import com.biglybt.pif.ui.tables.TableColumnInfo;
 import com.biglybt.ui.swt.Utils;
 import com.biglybt.ui.swt.views.table.CoreTableColumnSWT;
 import com.biglybt.ui.swt.views.table.TableCellSWT;
+import com.biglybt.ui.swt.views.table.utils.TableColumnSWTUtils;
 
 /** Size of Torrent cell
  *
@@ -113,15 +114,7 @@ public class SizeItem
 		}
 		cell.setText(s);
 
-		if (Utils.getUserMode() > 0 && (cell instanceof TableCellSWT)) {
-			if (value.size >= 0x40000000l) {
-				((TableCellSWT) cell).setTextAlpha(200 | 0x100);
-			} else if (value.size < 0x100000) {
-				((TableCellSWT) cell).setTextAlpha(180);
-			} else {
-				((TableCellSWT) cell).setTextAlpha(255);
-			}
-		}
+		TableColumnSWTUtils.setSizeAlpha( cell, size );
 	}
 
 	private static class sizeitemsort
